/* This is the STATA code for the "Materials Prices & Productivity" paper.  

For the program to work, the user first needs to run getdata.sas.  
In addition, the user needs to download a dataset 
called zipcodes, which contains the county, longitude, and latitutde of each U.S. zip code.  

The following csv files are produced by this .do file 

elasticityRegs.csv : "What is the elasticity of subst. between cement and sand/gravel in
                      concrete producers' production functions?"
persistRegs_1.csv  : "How persistent are buyer/supplier relationships in cement?"
persistRegs_2.csv  : "How persistent are buyer/supplier relationships in boxes?"
sampleStats.csv    : "Sample stats for establishments both inside and outside of the main sample"
regResults.csv     : "How do different TFP/Price measures vary with entry/exiting behaviour? "
                     "How persistent are different TFP/Price measures?"
correlations.csv   : "Correlations btw. different TFP/Price measures"
dispersions.csv    : "90/10 Ratios, 75/25 Ratios, standard deviations for
                      different TFP/Price distributions"
supplierRegs.csv   : "How much of input price variation or buyer's TFPQ is due to suppliers' TFPQ? " 
deviations.csv     : "In the CFS, what fraction of overall price variation is due
                      to within-plant price variation (i.e., something reminiscent of price 
                      descrimination)? "
elasticityCheck    : "Are the results robust to complementarity between materials and other inputs? 
merrror.csv,       :  "How are the results changed by moderate-to-large amounts of measurement error?"
acrossBuyer.csv    : "Are some of the within-supplier, cross-buyer variation in cement/paper prices due to 
                        the timing or size of the shipment?"
cavesResults.csv   : "Re-compute productivity using the index number method of Caves, Christensen and Diewert (1982)"
npwResults.csv     : "Compute correlations between the nonproduction worker share and plants' input/output prices 
                      and different productivity measures" 
profitsOnprice.csv : "Run a regression with profits on the left-hand side and materials prices on the right-hand-side " 
spatialResults     : "For the benchmark and quality variation samples, run a regression with materials prices on the left-
                     hand side and neighbors' (where the neighborhood is a 300-mile radius circle) on the right-hand side"

The run-time of the code greatly depends on whether the local macro variables runRegs, persist and/or 
skip are equal to 1. 

*/
clear
clear matrix
set more off
set matsize 1000
set scheme s1mono
 
local plocal=0 /* =1 if you want to compute the local prices for cement/paperboard shippers */
local shipCost=1  /* =1 if you want to incorporate shipping costs in the regressions of Section 5.  The default is =1  */
local priceCheck=1 /* =1 if you want to drop outlier shipments for the calculations of Section 4 */
local persist=0  /* =1 if you want to run the "persistance" regressions */
local skip=1    /* =1 if you want to skip (most of) the calculations of section 3  */
local limedist=0 /* =1 if you want to compute the "closeness" of each county from limestone production */
local outlie=log(3) /* Cut-off, for revmoing outlier observations */
local outlie2=log(4)   /* Cut-off for removing outlier observations, for the Section 4 regressions.  I use a slightly larger cut-off
                         so as not to drop observations (relative to a previous draft of a paper) */
local doCI=1 /* =1 if you want to create dispersionsCI and correlationsCI (confidence intervals for the decline in dispersion, correlations).   */
local makeplots=0   
local residRelPrice=0  
local runRegs=1   /* =1 if you want to run the regressions of Section 4.  This will take a couple hours to run (mainly because it takes so long 
                     to do compute the boostrapped "fake" declines of dispersions.   */
local spatial=0  /* =1 if you want to compute the spatial autocorrelation of materials prices for the bencmark sample 
                     and the quality-variation sample */
local caves=0    /* =1 if you want to do the robustness check related to computing plants' productivities in the manner of Caves Christensen and Diewert (1982) */  
local readCFS=0  /* =1 if you want to read in the .csv file called cfsFull.csv */

cap program drop myQuant
/* For confidentiality reasons, the Census does not allow quantiles of any variable, X, to be disclosed.
   However, the Census will allow quantiles of the kernel density of X to be disclosed.  The following program
   estimates the 10th, 25th, 75th, and 90th percentile of the kernel density of any variable X.  The second 
   argument of this program is the weight (for example revenue) with which to estimate the density */ 
program define myQuant, rclass
  qui { 
   kdensity `1' [aw=`2'], nograph gen(progXval progYval)
   gen progZval=sum(progYval)  /* Create the empirical cdf from the empirical pdf */
   sum progZval  
   replace progZval=progZval/r(max)  /* Normalize to make the variable an actual emprical cdf (i.e., the maximum value will of 
                                            progZval will now be equal to 1*/
   gen prog10=1 if progZval<.1 & progZval[_n+1]>.1  /* Find the observation for which the empirical cdf passes 0.1 */
   gen prog25=1 if progZval<.25 & progZval[_n+1]>.25
   gen prog75=1 if progZval<.75 & progZval[_n+1]>.75
   gen prog90=1 if progZval<.90 & progZval[_n+1]>.90
 
   /* The estimate of the 10th percentile will be a weighted average of the value of the variable that is right to the 
      left and right to the right of the 10th percentile.  The weights will be determined by the relative distance of 
      the empirical CDF to 0.1 */ 
   gen prog10pct=((.1-progZval)*progXval[_n+1]+(progZval[_n+1]-.1)*progXval)/((.1-progZval)+(progZval[_n+1]-.1)) if prog10==1  
   gen prog25pct=((.25-progZval)*progXval[_n+1]+(progZval[_n+1]-.25)*progXval)/((.25-progZval)+(progZval[_n+1]-.25)) if prog25==1
   gen prog75pct=((.75-progZval)*progXval[_n+1]+(progZval[_n+1]-.75)*progXval)/((.75-progZval)+(progZval[_n+1]-.75)) if prog75==1  
   gen prog90pct=((.9-progZval)*progXval[_n+1]+(progZval[_n+1]-.9)*progXval)/((.9-progZval)+(progZval[_n+1]-.9)) if prog90==1 
   sum prog10pct  /* There is only one observation in prog10pct.  By using the "sum" command, we can retrieve this one value */
   local r1=r(mean)  /* Store the 10th percentile in a local variable */
   sum prog25pct
   local r2=r(mean)
   sum prog75pct
   local r3=r(mean)
   sum prog90pct
   local r4=r(mean)
   return local r1 `"`r1'"'
   return local r2 `"`r2'"'
   return local r3 `"`r3'"'
   return local r4 `"`r4'"'
   drop prog*
   }  
end

if `readCFS'==1 {
  insheet using cfsFull.csv, clear
  save cfsFull, replace 
}

insheet using firmlocs.csv, clear
drop if zip5==. | firmid==0 | firmid==.  /* Drop firms with missing info */
ren zip5 dest_zip
ren firmid firmid1997
save firmlocs, replace

use ../../data/zipcodes 
sort zipcode
by zipcode: keep if _n==1
collapse (mean) longit latit, by(countyfips statefips)
replace countyfips=mod(countyfips,1000)  /* Get the "county" part from the county-state variable */
drop in 1/1
ren countyfips county
ren statefips state
save countylocs, replace

if `limedist'==1 {
  insheet using limestone.csv, clear
  drop if state==. | county==. 
  collapse (sum) empLime=emp (count) ctLime=emp, by(county state year)
  replace county=23 if county==25 & state==12  /* Fill-in missing county infor for a couple counties that are not in Ali's dataset */
  replace county=195 if county==193 & state==29
  merge n:1 county state using countylocs 
  drop if _merge==2
  drop _merge
  drop county state
  ren longit longitLimestone
  ren latit latitLimestone
  save limestone, replace
  keep if year==1977
  replace year=1972
  append using limestone
  save limestone, replace

  use countylocs, replace
  gen year=1972
  append using countylocs
  replace year=1977 if year==.
  append using countylocs
  replace year=1982 if year==.
  append using countylocs
  replace year=1987 if year==.
  joinby year using limestone
  gen mileage=sqrt( 69.31^2 * (latitude-latitLime)^2 + 53.0^2 * (longitude-longitLime)^2)  /* This is a formula to compute distance from 
                                                                                differences in  longitude and latitude */

  replace mileage=10 if mileage<=10  /* Count the number of limestone plants that are within 10 miles */
  gen distance1=empLime/mileage
  replace mileage=25 if mileage<=25
  gen distance2=empLime/mileage
  gen empClose50=empLime if mileage<=50
  gen empClose100=empLim if mileage<=100
  collapse (sum) distance* empClose* , by(county state year)
  save limestoneDistance, replace
}

if `skip'==0 {  /*  BEGINNING OF SKIP */

insheet using ppnlist.csv, clear
format ppn %12.0f
reshape long te ind firmid tvs cfn, i(ppn sampyes) j(year) 
ren firmid firmidPPNL
ren cfn cfnPPNL
ren tvs tvsPPNL
gen exist=(te~=.)
gen tochange=0
sort ppn year
replace tochange=1 if exist[_n-2]==1 & exist[_n-1]==0 & exist==1 & ppn==ppn[_n-1] & ppn==ppn[_n-2]
replace exist=1 if tochange[_n+1]==1 
gen exit=(exist[_n+1]==0) if year~=97 & exist==1
gen entry=(exist[_n-1]==0) if year~=63 & year~=67 & exist==1
gen young=(exist[_n-2]==0 & exist[_n-1]==1) if year~=63 & year~=67 & exist==1
replace year=year+1900
keep if exist==1
drop exist
drop if ind~=2026 & ind~=2041 & ind~=2281 & ind~=3273 & ind~=2061 & ind~=2095 & ind~=2653 & ind~=2911 & ind~=2011 & ind~=2013 & ind~=2035 & ind~=2084 & ind~=2421
save ppnlist, replace

insheet using cmat.csv, clear
save cmat, replace 
use cmat, replace
bys lbdnum year: gen fi=1 if _n==1
gen te=exp(lte)
count if group<=12 & fi==1 & group~=11 & year<=1997 & ( year~=1987 | lpq-lmatm>-log(1000)) & (group~=3  | year<=1992)     
/* Group=3 is concrete.  Drop concrete plants from 1992-1997 Group ll is carbon black.  Drop this group (as there are too few observations, in the end, to pass disclosure.
    The lpq-lmatm condition drops a very small number of observations, within ready-mix cocnrete, that seem to have contaminated data*/
save esum_4Nums_1, replace
local counterSamp1=r(N) 
sum te if group<=12 & fi==1 & group~=11 & year<=1997 & ( year~=1987 | lpq-lmatm>-log(1000))  & (group~=3  | year<=1992)
local meanSamp1=r(mean)
drop fi
drop if lbae==. | lmae==. | lte==. | lmatm==. | lmate==. | lpq==. | lbdnum==.  /* Drop plants, from the benchmark sample, with missing data */
bys lbdnum year: gen fi=1 if _n==1
count if group<=12 & fi==1 & group~=11  & year<=1997 & ( year~=1987 | lpq-lmatm>-log(1000))  & (group~=3  | year<=1992)
local counterSamp2=r(N)
sum te if group<=12 & fi==1 & group~=11 & year<=1997 & ( year~=1987 | lpq-lmatm>-log(1000))  & (group~=3  | year<=1992)
local meanSamp2=r(mean)
save esum_4Nums_2, replace
drop fi

keep if group~=.
replace m="0"+m if length(m)<6 
sort lbdnum year
by lbdnum year: egen s1=sum(mc)
gen lmc=log(mc)
gen lmqdc=log(mqdc)

drop if group==3 & ( year==1987 & lpq-lmatm<-log(1000) | year>=1992)
drop if group==11
/* Combine some materials */
replace m="131111" if m=="131112"
replace m="324101" if m=="324102" 
replace m="262106" if m=="262105" | m=="262108" | m=="263104" | m=="263103" | m=="263102"
replace m="011503" if m=="011521"
replace m="208401" if m=="208402"
replace m="282425" if m=="282426"
drop if substr(m,1,1)=="9" & length(m)==6 /* These are re-balancing/missing materials codes */
bys group: egen tt1=sum(mc)
bys group m: egen tt2=sum(mc)
gen fra=tt2/tt1
keep if fra>0.06  /* Keep materials for which spending constitutes more than 6% of the total amount spent on materials */
drop fra tt2 tt1
 
/* Identify suspicious prices, for before 1992; otherwise use 
materials quantity flag to drop imputed prices. 

*/

bys m year: gen xxx=_N
gen pri=round(log(mc/mqdc),.0001)  
by m year: egen mdprice=mode(pri)
gen priY=(abs(pri-mdprice)<.0005)  if mdprice~=.  /* Here, the presumption is that when the Census imputes a price for a given plant, it chooses the 
                                                 same price for all plants within an material-year.  Looking at data from >=1992, this seems to be 
                                                 a safe presumption */  
by m year: egen xxxq=sum(priY)
replace xxxq=xxxq/xxx
gen todrop=0
replace todrop=1 if (mqdcf=="C" | mqdcf=="RV" | mqdcf=="I" | mqdcf=="V") & year>=1992     
 /* From 1992 on, the Census of Manufacturers materials supplement has imputed-data flags.  Use these, when available. */
replace todrop=1 if xxx>=25 & xxxq>=.1 & priY==1 & year<1992          
/* In the pre-1992 period, drop observations that "seem" to be imputed.  The Census imputes missing values with the average for the industry-year.  Drop the cases in which
 the price is exactly equal to the industry-year average.  Note, one can check using data from 1992-1997 that this is a sensible thing to do. */
drop if todrop==1
bys lbdnum year: gen fi=1 if _n==1
count if group<=12 & fi==1 
local counterSamp3=r(N) 
sum te if group<=12 & fi==1 
local meanSamp3=r(mean)
save esum_4Nums_3, replace
drop fi

drop xxx* pri priY mdprice todrop 
drop if group>16
/* For ready-mix concrete, drop the small number of plants which do not 
  record purchases of both cement and gravel/sand */
gen yes1=(m=="324101" & mqdc>0 & mc>0 & mqdc<. & mc<.)
gen yes2=(m=="144201" & mqdc>0 & mc>0 & mqdc<. & mc<.)
bys ppn year: egen x1=sum(yes1)
bys ppn year: egen x2=sum(yes2)
gen x3=x1+x2
drop if group==3 & x3~=2    

drop yes1 yes2 x1-x3
sort ppn year m 
gen relquant=log(mqdc/mqdc[_n+1]) if ppn==ppn[_n+1] & year==year[_n+1] & group==3 
gen relprice=log(mc/mc[_n+1]*mqdc[_n+1]/mqdc) if ppn==ppn[_n+1] & year==year[_n+1] & group==3 

gen todrop=0 

forvalues yr=1972(5)1987 {
   qui sum relquant if group==3 & year==`yr'
   replace todrop=1 if group==3 & year==`yr' & abs(relquant-r(mean))>`outlie' & relquant<.
   qui sum relprice if group==3 & year==`yr'
   replace todrop=1 if group==3 & year==`yr' & abs(relprice-r(mean))>`outlie' & relprice<.
}
bys ppn year: egen todrop2=max(todrop)
drop if todrop2==1
drop relquant-relprice todrop todrop2

bys lbdnum year: gen fi=1 if _n==1
count if group<=12 & fi==1 
local counterSamp4=r(N)
sum te if group<=12 & fi==1
local meanSamp4=r(mean)
save esum_4Nums_4, replace

forvalues zx=1/4 {
  di "`counterSamp`zx'' `meanSamp`zx''"  
}

sort cfn year
by cfn year: egen s2=sum(mc)
gen share2=s2/vm
bys group year: egen numer1=sum(share2*vm)
by group year: egen denom1=sum(vm)
gen mnshare2=numer1/denom1
drop numer1 denom1
sort lbdnum year m
by lbdnum year m: egen mc2=sum(mc)
by lbdnum year m: egen mqdc2=sum(mqdc)
by lbdnum year m: gen nn=_N
drop mc mqdc
ren mc2 mc
ren mqdc2 mqdc
gen lcm=log(cm)
bys lbdnum year m: keep if _n==1
gen lprice=log(mc/mqdc)
gen lpriceout=log(priceout)
gen tfpq=exp(ltfpq)
gen ltfpr=ltfpq+lpriceout
gen diff=log(mc)-lcm
gen diff2=log(tvmc)-lcm
gsort lbdnum year -mc
keep if share2>.5         /* Drop plants that have less than fifty percent of their revenues from their primary product */
gen price=mc/mqdc
preserve
collapse (mean) lprice [aw=mc], by(m year)
ren lprice lpriceA
save t1, replace
restore 
sort m year
merge n:1 m year using t1
assert _merge==3
drop _merge
replace lprice=lprice-lpriceA
bys cfn year: gen fix=_N
drop if fix==1 & group==3
drop fix
bys group year: egen denom=sum(mc)
bys group m year: egen numer=sum(mc)
gen share=numer/denom
drop numer denom
bys lbdnum year : egen denom=sum(share)
by lbdnum year: egen numer=sum(exp(lprice)*share)
/* What if elasticity of substitution, between different material inputs, is lower ? */
by lbdnum year: egen numer1=sum((exp(lprice))^(1-.1)*share)  /* These are elasticities of substitution that correspond to 
                                                               Table "Dispersions_Elasticity" */
by lbdnum year: egen numer2=sum((exp(lprice))^(1-.3)*share)
by lbdnum year: egen numer3=sum((exp(lprice))^(1-.5)*share)
replace numer1=(numer1)^(1/(1-.1))  
replace numer2=(numer2)^(1/(1-.3))
replace numer3=(numer3)^(1/(1-.5))

forvalues x=1/3 { 
  replace numer`x'=numer if group~=3 & group~=11
}
gen ltvs=log(tvs)
gen lpriceP=log(numer/denom) 
gen lpriceP1=log(numer1/denom) 
gen lpriceP2=log(numer2/denom) 
gen lpriceP3=log(numer3/denom) 

ren tfpq tfpqOrig
gen pinOrig=exp(lpriceP)
gen poutOrig=exp(lpriceout)

qui sum piship if year==1972 & ind==2013
replace piship=r(mean) if year==1972 & ind==2011
qui sum piship if year==1972 & ind==2013
replace piship=r(mean) if year==1992 & ind==2011
bys group year: egen modepiout=mode(piship)
gen tvsOrig=exp(ltvs)/modepiout
replace tvs=tvs/modepiout
drop modepiout

sort lbdnum year m
drop fi
by lbdnum year: gen fi=1 if _n==1
gen lpriceE=log(ee/pe)
foreach var of varlist lpriceP* lpriceE  tvs ltvs ltfpq* ltfpr*  lpriceout tvsOrig tfpq  {
  by lbdnum year: replace `var'=. if fi~=1
}

sort group year

foreach var of varlist  ltfpq* lpriceP* lpriceE ltfpr*  ltvs lpriceout  {
 by group year: egen mn=mean(`var')
 replace `var'=`var'-mn
 cap drop mn
}
replace lpriceE=0 if pe==0 /* Just so the sample counts do not go down, impute plants that do not purchase any quantity of electricity (but do report values of electricity purchses) to pay the average price */

sort lbdnum year
gen todro=(fi==1 & (abs(lpriceout)>`outlie' | abs(lpriceP)>`outlie' | abs(ltfpq)>`outlie'))

by lbdnum year: egen todrop=max(todro)
drop if todrop==1
drop todro*

/* Price indices = geometric average */

bys group year: egen stvs=sum(tvsOrig)
by group year: egen pindex1=sum(tvsOrig*log(pinOrig))
by group year: egen pindex2=sum(tvsOrig*log(poutOrig))
replace pindex1=exp(pindex1/stvs)
replace pindex2=exp(pindex2/stvs)
gen tfprOrig=tfpqOrig*poutOrig/pindex2
gen tfpq3Orig=tfpqOrig*(pinOrig/pindex1)^(iam*mnshare2)

gen ltfpq3=log(exp(ltfpq)*(pimat/exp(lpriceP))^(-iam*mnshare2))
gen ltfpqE=log(exp(ltfpq)*(exp(lpriceE))^(iae))
gen ltfpq3E=log(exp(ltfpq3)*(exp(lpriceE))^(iae))   /* Here, we strip out not only materials price variation, but also electricity price variation.  See the footnote referencing Davis et al. (2008) */
gen ltfpq3_1=log(exp(ltfpq)*(pimat/exp(lpriceP1))^(-iam*mnshare2))  /* These are the phi productivity measures that correspond to the excersie in Appendix A.4 */
gen ltfpq3_2=log(exp(ltfpq)*(pimat/exp(lpriceP2))^(-iam*mnshare2))
gen ltfpq3_3=log(exp(ltfpq)*(pimat/exp(lpriceP3))^(-iam*mnshare2))
gen ltfpr3=log(exp(ltfpr)*(pimat/exp(lpriceP))^(-iam*mnshare2))

gen ltfpr_Wage=ltfpr+ial*(lte-log(sw))   /* Here, on the right hand side, labor is measured in dollars, instead of in hours */
gen ltfpq_Wage=ltfpq+ial*(lte-log(sw))
gen ltfpq3_Wage=ltfpq3+ial*(lte-log(sw))
gen ltfpq3_1_Wage=ltfpq3_1+ial*(lte-log(sw))
gen ltfpq3_2_Wage=ltfpq3_2+ial*(lte-log(sw))
gen ltfpq3_3_Wage=ltfpq3_3+ial*(lte-log(sw))

sort ppn year m
gen group2=17 if group==3 & div<=7
replace group2=18 if group==3 & div>7

/* Here we document that, for ready-mixed concrete, the 
   elasticity of substitution between cement and sand/gravel 
   is significantly greater than 0 */

save temp, replace
keep if group==3
merge n:1 ppn year using ppnlist
drop if _merge<3
drop _merge
sort ppn year m
gen relquant=log(mqdc/mqdc[_n+1]) if ppn==ppn[_n+1] & year==year[_n+1]
gen relcost=log(mc/mc[_n+1]) if ppn==ppn[_n+1] & year==year[_n+1]
gen relprice=log(mc/mc[_n+1]*mqdc[_n+1]/mqdc) if ppn==ppn[_n+1] & year==year[_n+1]
drop if m=="324101"  /* Keep only one observation per plant-year */
replace county=cou if county==.
replace state=fipsst if state==.
replace county=23 if county==25 & state==12  /* Fill-in missing county infor for a couple counties that are not in Ali's dataset */
replace county=51 if county==510 & state==13
replace county=775 if county==780 & state==51
merge n:1 county state year using limestoneDistance
drop if _merge==2
drop _merge
foreach var of varlist distance* {
   replace `var'=log(`var') 
}

xtset ppn

preserve 
gen coef1=.
gen coef2=.
gen coef3=.
gen se1=.
gen se2=.
gen se3=.
gen r2a=.
gen quant=.
replace empClose100=empClose100/1e3
gen empClose100_2=empClose100^2
gen empClose100_3=empClose100^3
gen ones=1
myQuant empClose100 ones
local r1_25=real(r(r2))
local r1_75=real(r(r3))
reg lpriceP i.year empClose100, cluster(ppn)
replace r2a=e(r2_a) in 1/1
replace coef1=_b[empClose100] in 1/1
replace se1=_se[empClose100] in 1/1
reg lpriceP i.year empClose100 empClose100_2, cluster(ppn)
replace r2a=e(r2_a) in 2/2
replace coef1=_b[empClose100] in 2/2
replace se1=_se[empClose100] in 2/2
replace coef2=_b[empClose100_2] in 2/2
replace se2=_se[empClose100_2] in 2/2
reg lpriceP i.year empClose100*, cluster(ppn)
replace r2a=e(r2_a) in 3/3
replace coef1=_b[empClose100] in 3/3
replace se1=_se[empClose100] in 3/3
replace coef2=_b[empClose100_2] in 3/3
replace se2=_se[empClose100_2] in 3/3
replace coef3=_b[empClose100_3] in 3/3
replace se3=_se[empClose100_3] in 3/3
replace quant= `r1_25' in 1/1
replace quant= `r1_75' in 2/2
keep coef* se*  quant r2a
keep in 1/3
outsheet using limestoneRegressions.csv, replace delim(,)
restore

gen coef1=.
gen coef2=.
gen coef3=.
gen coef4=.

gen loc="1"+string(fipsst)+string(cou)
destring loc, replace force

gen xt=loc*10000+year  /* Create a variable that is unique for each  county-year */

qui {
reg relquant relprice i.year, r
replace coef1=_b[relprice] in 1/1
replace coef2=_se[relprice] in 1/1
replace coef3=e(r2_a) in 1/1
replace coef4=e(N) in 1/1
reg relquant relprice i.year##i.div, r
replace coef1=_b[relprice] in 2/2
replace coef2=_se[relprice] in 2/2
replace coef3=e(r2_a) in 2/2
replace coef4=e(N) in 2/2
areg relquant relprice , r a(xt)
replace coef1=_b[relprice] in 3/3
replace coef2=_se[relprice] in 3/3 
replace coef3=e(r2_a) in 3/3
replace coef4=e(N) in 3/3
reg relquant relprice i.year if div<8, r
replace coef1=_b[relprice] in 4/4
replace coef2=_se[relprice] in 4/4
replace coef3=e(r2_a) in 4/4
replace coef4=e(N) in 4/4
reg relquant relprice i.year##i.div if div<8, r
replace coef1=_b[relprice] in 5/5
replace coef2=_se[relprice] in 5/5
replace coef3=e(r2_a) in 5/5
replace coef4=e(N) in 5/5
areg relquant relprice  if div<8, r a(xt)
replace coef1=_b[relprice] in 6/6
replace coef2=_se[relprice] in 6/6
replace coef3=e(r2_a) in 6/6
replace coef4=e(N) in 6/6

ivregress gmm relquant i.year (relprice=i.year distance1), r first   
ivregress gmm relquant i.year##i.div (relprice=i.year##i.div distance1), r first 
ivregress gmm relquant i.year (relprice=i.year distance1) if div<8, r first
ivregress gmm relquant i.year##i.div (relprice=i.year##i.div distance1) if div<8, r first  

}
keep coef* 
keep in 1/6
outsheet using elasticityRegs.csv, replace delim(,)

use temp, replace

/* De-mean */
sort group year
foreach var of varlist  ltfpq* lpriceP* ltfpr*  ltvs   lpriceout  {
 by group year: egen mn=mean(`var')
 replace `var'=`var'-mn
 cap drop mn
}
 
replace group=9 if group==10 /* Combine the two post-1992 cardboard box groups */

sort ppn year
merge n:1 ppn year using ppnlist
replace exit=(lastyear97<2002) if year==1997
sort group year
by group year: egen modeInd=mode(ind)

drop if (year<1970 | (year>=1992 & (ind==3273 | modeInd==3273))) | _merge==1

/* The S (NS) suffix here corresponds to the plants that are in the sample (not in the sample) .  These calculations are referenced in Appendix B */

gen empS=.      
gen empNS=.
gen tvsS=.
gen tvsNS=.
gen exitS=.
gen exitNS=.
gen entryS=.
gen entryNS=.
gen NS=.
gen NN=.
gen mainInd=.
qui sum piship if year==1972 & ind==2013
replace piship=r(mean) if year==1972 & ind==2011
qui sum piship if year==1972 & ind==2013
replace piship=r(mean) if year==1992 & ind==2011
bys ind year: egen modepiout=mode(piship)
gen ltvsPPNL=log(tvsPPNL/modepiout)
drop modepiout

/* Make plots */
if `makeplots'==1 {
preserve
keep if group>=13  & group<=16 & ltfpq~=.
lpoly ltfpq lpriceP [aw=tvs] , nograph at(lpriceP) gen(x1)
gen dev=(ltfpq-x1)^2
lpoly dev lpriceP [aw=tvs] , nograph at(lpriceP) gen(x2)
gen devA=x1
gen devB=x1+ sqrt(x2)
gen devC=x1- sqrt(x2)
drop x1 x2 dev
lpoly ltfpq3 lpriceP [aw=tvs], nograph at(lpriceP) gen(x1)
gen dev=(ltfpq3-x1)^2
lpoly dev lpriceP [aw=tvs], nograph at(lpriceP) gen(x2)
gen devA_3=x1 
gen devB_3=x1+ sqrt(x2)
gen devC_3=x1- sqrt(x2)
sort lpriceP
drop dev

/* These graphs do not appear in a paper.  (They were referenced in Appendix A2 in a previous version of the paper */

line devA devB devC lpriceP if abs(lpriceP)<.4, color(black black black) lwidth(medthick medthin medthin)  lpattern(solid solid solid) legend(off)  xtitle("Log Input Price") ytitle("Log Productivity")
graph export "correlation_graph_Quality_v2.eps", replace
line dev* lpriceP if abs(lpriceP)<.4, color(black black black red red red) lwidth(medthick medthin medthin medthick medthin medthin medthin)  lpattern(solid solid solid "-." "-." "-." ) legend(off)  xtitle("Log Input Price") ytitle("Log Productivity")
graph export "correlation_graph_Quality.eps", replace

restore

preserve
keep if group<=12 & ltfpq~=.
lpoly ltfpq lpriceP [aw=tvs] , nograph at(lpriceP) gen(x1)
gen dev=(ltfpq-x1)^2
lpoly dev lpriceP  [aw=tvs], nograph at(lpriceP) gen(x2)
gen devA=x1
gen devB=x1+ sqrt(x2)
gen devC=x1- sqrt(x2)
drop x1 x2 dev
lpoly ltfpq3 lpriceP [aw=tvs] , nograph at(lpriceP) gen(x1)
gen dev=(ltfpq3-x1)^2
lpoly dev lpriceP [aw=tvs], nograph at(lpriceP) gen(x2)
gen devA_3=x1 
gen devB_3=x1+ sqrt(x2)
gen devC_3=x1- sqrt(x2)
sort lpriceP
drop dev

line devA devB devC lpriceP if abs(lpriceP)<.4, color(black black black) lwidth(medthick medthin medthin)  lpattern(solid solid solid) legend(off) xtitle("Log Input Price") ytitle("Log Productivity")
graph export "correlation_graph_v2.eps", replace
line dev* lpriceP if abs(lpriceP)<.4, color(black black black red red red) lwidth(medthick medthin medthin medthick medthin medthin medthin)  lpattern(solid solid solid "-." "-." "-." ) legend(off) xtitle("Log Input Price") ytitle("Log Productivity") 
graph export "correlation_graph.eps", replace
restore

}

gen logemp=log(te)
bys ppn year: gen fix=1 if _n==1
qui {
 forvalues index=1/12 {
   if `index'~=10 & `index'~=11 {
   sum modeInd if group==`index' & fix==1
   local mI=r(max)
   replace mainInd=`mI' in `index'/`index'
   sum ltvsPPNL if fix==1 & group==`index'
   replace tvsS=r(mean) in `index'/`index'
   sum ltvsPPNL if fix==1 &  ind==`mI' & (group<13 | group==.)
   replace tvsNS=r(mean) in `index'/`index'

   sum logemp if  fix==1 &  group==`index'
   replace empS=r(mean) in `index'/`index'
   sum logemp if fix==1 &  ind==`mI' & (group<13 | group==.)
   replace empNS=r(mean) in `index'/`index'

   sum exit if fix==1 &  group==`index'
   replace exitS=r(mean) in `index'/`index'
   sum exit if  fix==1 & ind==`mI' & (group<13 | group==.)
   replace exitNS=r(mean) in `index'/`index'

   sum entry if fix==1 &  group==`index'
   replace entryS=r(mean) in `index'/`index'
   replace NS=r(N) in `index'/`index'
   sum entry if fix==1 &  ind==`mI' & (group<13 | group==.)
   replace entryNS=r(mean) in `index'/`index'
   replace NN=r(N) in `index'/`index'
   }
}
   sum ltvsPPNL if fix==1 & group<13
   replace tvsS=r(mean) in 13/13 
   sum ltvsPPNL if fix==1 & (group<13 | (ind~=2084 &  ind~=2011 & ind~=2013 & ind~=2035 & ind~=2421) ) 
   replace tvsNS=r(mean) in 13/13

   sum logemp if  fix==1 & group<13
   replace empS=r(mean) in 13/13
   sum logemp if fix==1 & (group<13 | ( ind~=2084 &  ind~=2011 & ind~=2013 & ind~=2035 & ind~=2421))
   replace empNS=r(mean) in 13/13

   sum exit if fix==1 & group<13
   replace exitS=r(mean) in 13/13
   sum exit if  fix==1 & (group<13 | (ind~=2084 &  ind~=2011 & ind~=2013 & ind~=2035 & ind~=2421))
   replace exitNS=r(mean) in 13/13

   sum entry if fix==1 & group<13
   replace entryS=r(mean) in 13/13
   replace NS=r(N) in 13/13
   sum entry if fix==1 & (group<13 | (ind~=2084 &  ind~=2011 & ind~=2013 & ind~=2035 & ind~=2421))
   replace entryNS=r(mean) in 13/13
   replace NN=r(N) in 13/13
}

save temp, replace
keep in 1/13
drop in 10/10
keep empS-mainInd
outsheet using sampleStats.csv, replace delim(,)

use temp, replace
keep if m~=""
bys group m: egen m1=sum(mc)
bys group: egen m2=sum(vm*fi)
by group : egen count=sum(fi)
gen fra=m1/m2
sort group m
by group m: keep if _n==1
keep group m fra count
outsheet using matShares.csv, replace delim(,)

use temp, replace
drop fix ltvsPPNL logemp
/* Firmid is missing in 1972, in my dataset (which was drawn from the lbd).  For disclosure purposes, impute it. */
  replace firmid=cfn if cfn<1e9 & year==1972
  replace firmid=floor(cfn/10000) if cfn>1e9 & cfn<. & year==1972  
save esumSamp1, replace

/* How would measurement error affect the results? */

use esumSamp1, replace
gen error1=rnormal()
gen error2=rnormal()
forvalues x=0/10 {
  gen error1_`x'=error1*`x'/100
  gen error2_`x'=error2*`x'/100
  gen lpriceout_error_`x'=lpriceout+error1_`x'
  gen lpriceP_error_`x'=lpriceP+error2_`x'
  gen ltfpq_error_`x'=ltfpq-error1_`x'
  gen ltfpq3_error_`x'=log(exp(ltfpq_error_`x')*(pimat/exp(lpriceP_error_`x'))^(-iam*mnshare2))
}

keep if group<=12
sort lbdnum year m
drop fi
by lbdnum year: gen fi=1 if _n==1
keep if fi==1
foreach var of varlist *error* {
  by lbdnum year: replace `var'=. if fi~=1
}

sort lbdnum year
by group year: egen summat=sum(mc)
gen lnn=log(summat)-lpriceP
sort group year
foreach var of varlist *_error*  lnn lpq {
 by group year: egen mn=mean(`var')
 replace `var'=`var'-mn
 cap drop mn
}

forvalues x=1/7 {
  gen cor`x'=.
}
forvalues x=1/5 {
  gen sd`x'=.
}
forvalues x=1/12 {
  gen per`x'=.
}

/* These calculations produce the material referenced in Appendix A.7 */

gen aa2=year*10000+group*100 
xtset ppn year

forvalues x=1/10 {
   qui cor lpriceP_error_`x'  ltfpq_error_`x' [aw=tvs]
   qui replace cor1=r(rho) in `x'/`x'  
   qui cor lpriceP_error_`x'  ltfpq3_error_`x' [aw=tvs]
   qui replace cor2=r(rho) in `x'/`x'  
   qui cor lpriceP_error_`x'  lpriceout_error_`x' [aw=tvs]
   qui replace cor3=r(rho) in `x'/`x'  
   qui cor ltfpq_error_`x'  ltfpq3_error_`x' [aw=tvs]
   qui replace cor4=r(rho) in `x'/`x'  
   qui cor ltfpq_error_`x'  ltfpr [aw=tvs]
   qui replace cor5=r(rho) in `x'/`x'  
   qui cor ltfpq_error_`x'  lpriceout_error_`x' [aw=tvs]
   qui replace cor6=r(rho) in `x'/`x'  
   qui cor ltfpr  lpriceP_error_`x' [aw=tvs]
   qui replace cor7=r(rho) in `x'/`x'  
   qui sum ltfpr [aw=tvs]
   qui replace sd1=r(sd) in `x'/`x' 
   qui sum ltfpq_error_`x'    [aw=tvs]
   qui replace sd2=r(sd) in `x'/`x'  
   qui sum ltfpq3_error_`x' [aw=tvs]
   qui replace sd3=r(sd) in `x'/`x'  
   qui sum lpriceout_error_`x' [aw=tvs]
   qui replace sd4=r(sd) in `x'/`x'  
   qui sum lpriceP_error_`x'    [aw=tvs]
   qui replace sd5=r(sd) in `x'/`x'  
   qui  areg ltfpq_error_`x' l5.ltfpq_error_`x'  [aw=tvs] , cluster(ppn) a(aa2)
   qui replace pers1=_b[ l5.ltfpq_error_`x'] in `x'/`x'
   qui replace pers2=_se[ l5.ltfpq_error_`x'] in `x'/`x'
   qui  areg ltfpq3_error_`x' l5.ltfpq3_error_`x'  [aw=tvs] , cluster(ppn) a(aa2) 
   qui replace pers3=_b[ l5.ltfpq3_error_`x'] in `x'/`x'
   qui replace pers4=_se[ l5.ltfpq3_error_`x'] in `x'/`x'
   qui  areg ltfpr l5.ltfpr  [aw=tvs] , cluster(ppn) a(aa2) 
   qui replace pers5=_b[ l5.ltfpr] in `x'/`x'
   qui replace pers6=_se[ l5.ltfpr] in `x'/`x'
   qui  areg ltvs l5.ltvs  [aw=tvs] , cluster(ppn) a(aa2) 
   qui replace pers7=_b[ l5.ltvs] in `x'/`x'
   qui replace pers8=_se[ l5.ltvs] in `x'/`x'
   qui  areg lpriceP_error_`x' l5.lpriceP_error_`x'  [aw=tvs] , cluster(ppn) a(aa2) 
   qui replace pers9=_b[ l5.lpriceP_error_`x'] in `x'/`x'
   qui replace pers10=_se[ l5.lpriceP_error_`x'] in `x'/`x'
   qui  areg lpriceout_error_`x' l5.lpriceout_error_`x'  [aw=tvs] , cluster(ppn) a(aa2) 
   qui replace pers11=_b[ l5.lpriceout_error_`x'] in `x'/`x'
   qui replace pers12=_se[ l5.lpriceout_error_`x'] in `x'/`x'
}
keep cor1-pers12
keep in 1/10
outsheet using "merror.csv", replace delim(,)
use esumSamp1, replace
keep if year>=1992 & group==9
keep lbdnum year firmid tvs
bys lbdnum year: keep if _n==1
ren lbdnum lbdnumd
save boxesSamp, replace

use esumSamp1, replace
keep if year>=1987 & group==3
keep lbdnum firmid tvs
bys lbdnum: keep if _n==1
ren lbdnum lbdnumd
save concreteSamp, replace

use esumSamp1, replace
drop if _merge==2  /* Drop observations that are not in main sample */
drop _merge

gen count=.
gen ones=1
forvalues xx=1/16 {
  qui gen cor`xx'=.
}

forvalues xx=1/7 {
  gen sds`xx'=.
  gen skew`xx'=.
}

gen weightCor=ones
qui {
forvalues w=0/1 {
 if `w'==1 {
  replace weightCor=tvs
}
forvalues x=1/21  {
local xg=`x'+21*`w'
local cond="if ltfpq~=. & group=="
local cond2=`x'
if `x'==17 |  `x'==18 {
   local cond="if ltfpq~=. & group2=="
}
if `x'==19  | `x'==21 {
 local cond="if group<=12 & ltfpq~=.  "
 local cond2=" "
}
if `x'==20 {
 local cond="if group>12 & group<=16  & ltfpq~=."
 local cond2=" " 
}
local suff2=" " 
if `x'==21 {
 local suff2="_Wage"
}

if `x' ~=10 & `x'~=11 {

count `cond'`cond2' 
local z=r(N) 
replace count=r(N) in `xg'/`xg'
cor lpriceP ltfpq`suff2' `cond'`cond2'  [aw=weightCor]
replace cor1=r(rho)  in `xg'/`xg'
cor lpriceP ltfpq3`suff2'  `cond'`cond2' [aw=weightCor]
replace cor2=r(rho)  in `xg'/`xg'
cor lpriceP ltfpr`suff2' `cond'`cond2' [aw=weightCor]
replace cor3=r(rho)  in `xg'/`xg'
cor lpriceP lpriceout `cond'`cond2' [aw=weightCor]
replace cor4=r(rho)  in `xg'/`xg'
cor ltfpq`suff2' ltfpq3`suff2'  `cond'`cond2' [aw=weightCor]
replace cor5=r(rho)  in `xg'/`xg'
cor ltfpq`suff2' ltfpr`suff2' `cond'`cond2' [aw=weightCor]
replace cor6=r(rho)  in `xg'/`xg'
cor ltfpq`suff2' lpriceout `cond'`cond2' [aw=weightCor]
replace cor7=r(rho)  in `xg'/`xg'
cor ltfpq3`suff2'  ltfpr`suff2' `cond'`cond2' [aw=weightCor]
replace cor8=r(rho)  in `xg'/`xg'
cor ltfpq3`suff2'  lpriceout `cond'`cond2' [aw=weightCor]
replace cor9=r(rho)  in `xg'/`xg'
cor ltfpr`suff2' lpriceout `cond'`cond2' [aw=weightCor]
replace cor10=r(rho)  in `xg'/`xg'
cor ltfpq3_1`suff2' ltfpq3`suff2'  `cond'`cond2' [aw=weightCor]
replace cor11=r(rho)  in `xg'/`xg'
cor ltfpq3_2`suff2' ltfpq3`suff2'  `cond'`cond2' [aw=weightCor]
replace cor12=r(rho)  in `xg'/`xg'
cor ltfpq3_3`suff2' ltfpq3`suff2'  `cond'`cond2' [aw=weightCor]
replace cor13=r(rho)  in `xg'/`xg'
cor ltfpq3_1`suff2' lpriceP `cond'`cond2' [aw=weightCor]
replace cor14=r(rho)  in `xg'/`xg'
cor ltfpq3_2`suff2' lpriceP `cond'`cond2' [aw=weightCor]
replace cor15=r(rho)  in `xg'/`xg'
cor ltfpq3_3`suff2' lpriceP `cond'`cond2' [aw=weightCor]
replace cor16=r(rho)  in `xg'/`xg'

sum lpriceP `cond'`cond2'  [aw=weightCor], detail
replace sds1=r(sd) in `xg'/`xg'
replace skew1=r(skewness) in `xg'/`xg'
sum lpriceout  `cond'`cond2' [aw=weightCor], detail
replace sds2=r(sd) in `xg'/`xg'
replace skew2=r(skewness) in `xg'/`xg'
sum ltfpq`suff2'  `cond'`cond2' [aw=weightCor] , detail
replace sds3=r(sd) in `xg'/`xg'
replace skew3=r(skewness) in `xg'/`xg'
sum ltfpq3_1`suff2'  `cond'`cond2' [aw=weightCor] , detail
replace sds4=r(sd) in `xg'/`xg'
replace skew4=r(skewness) in `xg'/`xg'
sum ltfpq3_2`suff2'  `cond'`cond2' [aw=weightCor], detail
replace sds5=r(sd) in `xg'/`xg'
replace skew5=r(skewness) in `xg'/`xg'
sum ltfpq3_3`suff2'  `cond'`cond2' [aw=weightCor], detail
replace sds6=r(sd) in `xg'/`xg'
replace skew6=r(skewness) in `xg'/`xg'
sum ltfpr`suff2' `cond'`cond2' [aw=weightCor], detail
replace sds7=r(sd) in `xg'/`xg'
replace skew7=r(skewness) in `xg'/`xg'
}
}
}
}
save temp, replace
keep in 1/42
keep cor* count sds* skew*
outsheet using correlations.csv, replace delim(,)

/* Compute Confidence intervals, via bootstrapping, for correlations */

if `doCI'==1{ 
forvalues xx=1/1000 {
di `xx'
qui {
forvalues w=0/1 {
forvalues x=1/21  {
local xg=`x'+21*`w'
local cond="if ltfpq~=. & group=="
local cond2=`x'
if `x'==17 |  `x'==18 {
   local cond="if ltfpq~=. & group2=="
}
if `x'==19  | `x'==21 {
 local cond="if group<=12 & ltfpq~=.  "
 local cond2=" "
}
if `x'==20 {
 local cond="if group>12 & group<=16  & ltfpq~=."
 local cond2=" " 
}
local suff2=" " 
if `x'==21 {
 local suff2="_Wage"
}

use if _merge~=2 using esumSamp1, replace
bsample, strata(group year)

foreach var of varlist  ltfpq* lpriceP* ltfpr*  ltvs   lpriceout  {
 by group year: egen mn=mean(`var')
 replace `var'=`var'-mn
 cap drop mn
}

gen ones=1
gen weightCor=ones
if `w'==1 {
  replace weightCor=tvs
}

if `x' ~=10 & `x'~=11 {

cor lpriceP ltfpq`suff2' `cond'`cond2'  [aw=weightCor]
local co1_`xg'_`xx'=r(rho)
cor lpriceP ltfpq3`suff2'  `cond'`cond2' [aw=weightCor]
local co2_`xg'_`xx'=r(rho)
cor lpriceP ltfpr`suff2' `cond'`cond2' [aw=weightCor]
local co3_`xg'_`xx'=r(rho)
cor lpriceP lpriceout `cond'`cond2' [aw=weightCor]
local co4_`xg'_`xx'=r(rho)
cor ltfpq`suff2' ltfpq3`suff2'  `cond'`cond2' [aw=weightCor]
local co5_`xg'_`xx'=r(rho)
cor ltfpq`suff2' ltfpr`suff2' `cond'`cond2' [aw=weightCor]
local co6_`xg'_`xx'=r(rho)
cor ltfpq`suff2' lpriceout `cond'`cond2' [aw=weightCor]
local co7_`xg'_`xx'=r(rho)
cor ltfpq3`suff2'  ltfpr`suff2' `cond'`cond2' [aw=weightCor]
local co8_`xg'_`xx'=r(rho)
cor ltfpq3`suff2'  lpriceout `cond'`cond2' [aw=weightCor]
local co9_`xg'_`xx'=r(rho)
cor ltfpr`suff2' lpriceout `cond'`cond2' [aw=weightCor]
local co10_`xg'_`xx'=r(rho)

}
}
}
}
}

forvalues gg=1/10 {
  forvalues hh=1/42 {
    if `hh'~= 10 & `hh' ~= 11 & `hh' ~= 31 & `hh' ~= 32 {
  gen co`gg'_`hh'=.
  forvalues xx=1/1000  {
  qui replace co`gg'_`hh'= `co`gg'_`hh'_`xx'' in `xx'/`xx'
}
}
}
}

foreach var of varlist co1_1 - co10_42 {
  sort `var' 
  local `var'g1=1/2*(`var'[25]+`var'[26])
  local `var'g2=1/2*(`var'[975]+`var'[976]) 

}

foreach var of varlist co1_1 - co10_42 {
  qui replace `var'=``var'g1' in 1/1
  qui replace `var'=``var'g2' in 2/2

}

keep co1_1-co10_42
keep in  1/2
gen x=_n
reshape long co1_ co2_ co3_ co4_ co5_ co6_ co7_ co8_ co9_ co10_ , i(x) j(var)
sort var x 
outsheet using correlationsCI.csv, replace delim(,)
}

use temp, replace

graph twoway (kdensity lpriceP  [aw=tvs] if  group2==17 , lcolor(black) lwidth(thick) lpattern("--")) (kdensity lpriceP  [aw=tvs]  if group2==18, lcolor(black)) , xtitle("Log Input Price") ytitle("") legend(off)
graph export "quality1.eps", replace

graph twoway (lpoly  ltfpq lpriceP if abs(lpriceP)<.4 & group2==17 [aw=tvs], lcolor(black) lwidth(thick) lpattern("--")) (lpoly  ltfpq lpriceP if abs(lpriceP)<.4 & group2==18  [aw=tvs], lcolor(black)) , xtitle("Log Input Price") ytitle("Log TFPQ") legend(off)
graph export "quality2.eps", replace

sort ppn year ltfpq 
save temp, replace
by ppn year: keep if _n==1
xtset ppn year
drop if group>12
gen name=""
replace name="Beta" if _n==1 | _n==4 | (_n>=8 & _n<24 & mod(_n,2)==0)
replace name="Persist" if _n==3 | _n==6
replace name="SE" if _n==2 | _n==5 | _n==5 | (_n>=8 & _n<24 & mod(_n,2)==1)
replace name="Count" if _n==7 | _n==24

gen weight="Y"
replace weight="N" if (_n>3 & _n<6) | (_n==10 | _n==11) |  (_n==14 | _n==15)| (_n==18 | _n==19) |  (_n==22 | _n==23) 
replace weight="" if _n==7 | _n==24
save esumEntryExit, replace

gen lIn=log(mc*share2)-lpriceP
sort group year
foreach var of varlist lIn lpq {
  by group year: egen m1=mean(`var')
  gen `var'D=`var'-m1
  cap drop m1
}

gen aa1=year*10000+group*100+div  /* Create a variable that is unique for each year-group-division combination */
gen aa2=year*10000+group*100      /* Create a variable that is unique for each year-group combination.  This is the specification that is reported in the paper.*/

sort ppn year

qui{
foreach var of varlist ltfpq* ltfpr ltvs lpriceP lpriceout lpqD lInD{
    gen `var'_Coeffs=.
    areg `var' l5.`var' , cluster(ppn) a(aa2)
    replace `var'_Coeffs = _b[l5.`var'] in 1/1
    replace `var'_Coeffs = _se[l5.`var'] in 2/2
    replace `var'_Coeffs = (_b[l5.`var'])^(0.2) in 3/3
    areg `var' l5.`var'  [aw=tvs], cluster(ppn) a(aa2)
    replace `var'_Coeffs = _b[l5.`var'] in 4/4
    replace `var'_Coeffs = _se[l5.`var'] in 5/5
    replace `var'_Coeffs = (_b[l5.`var'])^(0.2) in 6/6  
    replace `var'_Coeffs=e(N) in 7/7
    areg `var' entry , cluster(ppn) a(aa2)
    replace `var'_Coeffs=_b[entry] in 8/8
    replace `var'_Coeffs=_se[entry] in 9/9
    areg `var' entry  [aw=tvs], cluster(ppn) a(aa2)
    replace `var'_Coeffs=_b[entry] in 10/10
    replace `var'_Coeffs=_se[entry] in 11/11
    areg `var' entry , cluster(ppn) a(aa1)
    replace `var'_Coeffs=_b[entry] in 12/12
    replace `var'_Coeffs=_se[entry] in 13/13
    areg `var' entry  [aw=tvs], cluster(ppn) a(aa1)
    replace `var'_Coeffs=_b[entry] in 14/14
    replace `var'_Coeffs=_se[entry] in 15/15
    areg `var' exit , cluster(ppn) a(aa2)
    replace `var'_Coeffs=_b[exit] in 16/16
    replace `var'_Coeffs=_se[exit] in 17/17
    areg `var' exit  [aw=tvs], cluster(ppn) a(aa2)
    replace `var'_Coeffs=_b[exit] in 18/18
    replace `var'_Coeffs=_se[exit] in 19/19
     areg `var' exit , cluster(ppn) a(aa1)
    replace `var'_Coeffs=_b[exit] in 20/20
    replace `var'_Coeffs=_se[exit] in 21/21
    areg `var' exit [aw=tvs], cluster(ppn) a(aa1)
    replace `var'_Coeffs=_b[exit] in 22/22
    replace `var'_Coeffs=_se[exit] in 23/23
    replace `var'_Coeffs=e(N) in 24/24
}
}

drop aa1 aa2

gen reg1=.
gen reg2=.
gen reg3=.
gen reg4=.
gen reg5=.
gen reg6=.
gen reg7=.
gen name2=""
replace name2="TFPR" if mod(_n,8)==1 | mod(_n,8)==2
replace name2="TFPQ" if mod(_n,8)==3 | mod(_n,8)==4
replace name2="Phi"  if mod(_n,8)==5 | mod(_n,8)==6
replace name2="Input Price" if mod(_n,8)==7 | mod(_n,8)==0

/* These regressions do not appear in the paper (they were in a previous version of the paper).  They 
are similar to the regressions of Section 3.4 .  Instead of comparing the prices/productivities of
 entrants vs. incumbents and exiting plants vs. survivors (as in the paper, these regressions compare
  the probability of exit for plants with high vs. low productivity and high vs. low materials prices.
  */

qui {
logit exit ltfpr i.group i.year , cluster(ppn)
replace reg1 =_b[ltfpr] in 1/1
replace reg1 =_se[ltfpr] in 2/2
replace reg1 = e(N) in 19/19
logit exit ltfpq i.group i.year , cluster(ppn)
replace reg2 =_b[ltfpq] in 3/3
replace reg2 =_se[ltfpq] in 4/4
replace reg2 = e(N) in 19/19
logit exit ltfpq3 i.group i.year , cluster(ppn)
replace reg3 =_b[ltfpq3] in 5/5
replace reg3 =_se[ltfpq3] in 6/6
replace reg3 = e(N) in 19/19
logit exit lpriceP i.group i.year , cluster(ppn)
replace reg4 =_b[lpriceP] in 7/7
replace reg4 =_se[lpriceP] in 8/8
replace reg4 = e(N) in 19/19
logit exit lpriceP ltfpr i.group i.year , cluster(ppn)
replace reg5 =_b[ltfpr] in 1/1
replace reg5 =_se[ltfpr] in 2/2
replace reg5 =_b[lpriceP] in 7/7
replace reg5 =_se[lpriceP] in 8/8
replace reg5 = e(N) in 19/19
logit exit lpriceP ltfpq i.group i.year , cluster(ppn)
replace reg6 =_b[ltfpq] in 3/3
replace reg6 =_se[ltfpq] in 4/4
replace reg6 =_b[lpriceP] in 7/7
replace reg6 =_se[lpriceP] in 8/8
replace reg6 = e(N) in 19/19
logit exit lpriceP ltfpq3 i.group i.year , cluster(ppn)
replace reg7 =_b[ltfpq3] in 5/5
replace reg7 =_se[ltfpq3] in 6/6
replace reg7 =_b[lpriceP] in 7/7
replace reg7 =_se[lpriceP] in 8/8
replace reg7 = e(N) in 19/19
logit exit ltfpr i.group i.year##i.reg i.div , cluster(ppn)
replace reg1 =_b[ltfpr] in 9/9
replace reg1 =_se[ltfpr] in 10/10
replace reg1 = e(N) in 20/20
logit exit ltfpq i.group i.year##i.reg i.div , cluster(ppn)
replace reg2 =_b[ltfpq] in  11/11
replace reg2 =_se[ltfpq] in 12/12
replace reg2 = e(N) in 20/20
logit exit ltfpq3 i.group i.year##i.reg i.div , cluster(ppn)
replace reg3 =_b[ltfpq3] in 13/13
replace reg3 =_se[ltfpq3] in 14/14
replace reg3 = e(N) in 20/20
logit exit lpriceP i.group i.year##i.reg i.div , cluster(ppn)
replace reg4 =_b[lpriceP] in 15/15
replace reg4 =_se[lpriceP] in 16/16
replace reg4 = e(N) in 20/20
logit exit lpriceP ltfpr i.group i.year##i.reg i.div , cluster(ppn)
replace reg5 =_b[ltfpr] in 9/9
replace reg5 =_se[ltfpr] in 10/10
replace reg5 =_b[lpriceP] in 15/15
replace reg5 = e(N) in 20/20
replace reg5 =_se[lpriceP] in 16/16
logit exit lpriceP ltfpq i.group i.year##i.reg i.div , cluster(ppn)
replace reg6 =_b[ltfpq] in 11/11
replace reg6 =_se[ltfpq] in 12/12
replace reg6 =_b[lpriceP] in 15/15
replace reg6 =_se[lpriceP] in 16/16
replace reg6 = e(N) in 20/20
logit exit lpriceP ltfpq3 i.group i.year##i.reg i.div , cluster(ppn)
replace reg7 =_b[ltfpq3] in 13/13
replace reg7 =_se[ltfpq3] in 14/14
replace reg7 =_b[lpriceP] in 15/15
replace reg7 =_se[lpriceP] in 16/16
replace reg7 = e(N) in 20/20
}

format reg* *Coeffs %12.4f
keep name weight name2 *Coeffs reg1-reg7
keep in 1/24 
outsheet using regResults.csv, delim(,) replace

use temp, replace
cap gen ones=1

foreach var of varlist ltfpq* ltfpr* lpriceP lpriceout {
qui {
gen ninetyten`var'=.
gen ninetytenW`var'=.
gen iqr`var'=.
gen iqrW`var'=.
gen ninetyten`var'_Disc=.
gen ninetytenW`var'_Disc=.
gen iqr`var'_Disc=.
gen iqrW`var'_Disc=.
gen sd`var'=.
gen sdW`var'=.
gen counts`var'=.

forvalues x=1/16 {
   if `x' ~= 10  & `x'~=11 {
   local y=`x'
   gen `var'G=`var' if group==`x'
   _pctile `var'G [aw=tvs], p(9 11   24  26  74 76  89  91 )
   replace ninetytenW`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in `y'/`y'
   replace iqrW`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in `y'/`y'
   myQuant `var'G tvs
   replace ninetytenW`var'_Disc=real(r(r4))-real(r(r1)) in `y'/`y'
   replace iqrW`var'_Disc=real(r(r3))-real(r(r2))  in `y'/`y'
   _pctile `var'G , p(9 11   24  26  74 76  89  91 )
   replace ninetyten`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in `y'/`y'
   replace iqr`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in `y'/`y'
   myQuant `var'G ones
   replace ninetyten`var'_Disc=real(r(r4))-real(r(r1)) in `y'/`y'
   replace iqr`var'_Disc=real(r(r3))-real(r(r2))  in `y'/`y'
   sum `var'G [aw=tvs]
   replace sdW`var'=r(sd) in `y'/`y'
   replace counts`var'=r(N) in `y'/`y'
   sum `var'G
   replace sd`var'=r(sd) in `y'/`y'
   drop `var'G
  }
}

forvalues x=17/18 {
   local y=`x'
   gen `var'G=`var' if group2==`x'
   _pctile `var'G [aw=tvs], p(9 11   24  26  74 76  89  91 )
   replace ninetytenW`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in `y'/`y'
   replace iqrW`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in `y'/`y'
   myQuant `var'G tvs
   replace ninetytenW`var'_Disc=real(r(r4))-real(r(r1)) in `y'/`y'
   replace iqrW`var'_Disc=real(r(r3))-real(r(r2))  in `y'/`y'
   _pctile `var'G , p(9 11   24  26  74 76  89  91 )
   replace ninetyten`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in `y'/`y'
   replace iqr`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in `y'/`y'
   myQuant `var'G ones
   replace ninetyten`var'_Disc=real(r(r4))-real(r(r1)) in `y'/`y'
   replace iqr`var'_Disc=real(r(r3))-real(r(r2))  in `y'/`y'
   sum `var'G [aw=tvs]
   replace sdW`var'=r(sd) in `y'/`y'
   replace counts`var'=r(N) in `y'/`y'
   sum `var'G
   replace sd`var'=r(sd) in `y'/`y'
   drop `var'G
}
   
   gen `var'G = `var' if group<=12
   _pctile `var'G [aw=tvs], p(9 11   24  26  74 76  89  91 )
   replace ninetytenW`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in 19/19
   replace iqrW`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in 19/19
   myQuant `var'G tvs
   replace ninetytenW`var'_Disc=real(r(r4))-real(r(r1)) in 19/19
   replace iqrW`var'_Disc=real(r(r3))-real(r(r2))  in 19/19
   _pctile `var'G , p(9 11   24  26  74 76  89  91 )
   replace ninetyten`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in 19/19
   replace iqr`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in 19/19
   myQuant `var'G ones
   replace ninetyten`var'_Disc=real(r(r4))-real(r(r1)) in 19/19
   replace iqr`var'_Disc=real(r(r3))-real(r(r2))  in 19/19
   sum `var'G [aw=tvs]
   replace sdW`var'=r(sd) in 19/19
   replace counts`var'=r(N) in 19/19
   sum `var'G
   replace sd`var'=r(sd) in 19/19
   drop `var'G

   gen `var'G = `var' if group>12 & group<=16
   _pctile `var'G [aw=tvs], p(9 11   24  26  74 76  89  91 )
   replace ninetytenW`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in 20/20
   replace iqrW`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in 20/20
   myQuant `var'G tvs
   replace ninetytenW`var'_Disc=real(r(r4))-real(r(r1)) in 20/20
   replace iqrW`var'_Disc=real(r(r3))-real(r(r2))  in 20/20
   _pctile `var'G , p(9 11   24  26  74 76  89  91 )
   replace ninetyten`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in 20/20
   replace iqr`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in 20/20
   myQuant `var'G ones
   replace ninetyten`var'_Disc=real(r(r4))-real(r(r1)) in 20/20
   replace iqr`var'_Disc=real(r(r3))-real(r(r2))  in 20/20
   sum `var'G [aw=tvs]
   replace sdW`var'=r(sd) in 20/20
   replace counts`var'=r(N) in 20/20
   sum `var'G
   replace sd`var'=r(sd) in 20/20
   drop `var'G
  }
}

keep *_Disc sd* counts*
drop sds*
format *_Disc sd* %12.4f
keep in 1/20
drop in 11/11
drop in 10/10
outsheet using dispersions.csv, replace delim(,)

/* Here is the code to produce (some of the) Tables in Appendix C of the 
 paper.  */

if `doCI'==1 {
forvalues xxx=1/1000 {               
di `xxx'
use temp, replace
bsample, strata(group year)

foreach var of varlist  ltfpq* lpriceP* ltfpr*  ltvs   lpriceout  {
 by group year: egen mn=mean(`var')
 replace `var'=`var'-mn
 cap drop mn
}

cap gen ones=1

foreach var of varlist ltfpq ltfpq3 ltfpr {
qui {
gen ninetyten`var'=.
gen ninetytenW`var'=.
gen iqr`var'=.
gen iqrW`var'=.
gen ninetyten`var'_Disc=.
gen ninetytenW`var'_Disc=.
gen iqr`var'_Disc=.
gen iqrW`var'_Disc=.
gen sd`var'=.
gen sdW`var'=.
gen counts`var'=.

forvalues x=1/16 {
   if `x' ~= 10  & `x'~=11 {
   local y=`x'
   gen `var'G=`var' if group==`x'
   _pctile `var'G [aw=tvs], p(9 11   24  26  74 76  89  91 )
   replace ninetytenW`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in `y'/`y'
   replace iqrW`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in `y'/`y'
   myQuant `var'G tvs
   replace ninetytenW`var'_Disc=real(r(r4))-real(r(r1)) in `y'/`y'
   replace iqrW`var'_Disc=real(r(r3))-real(r(r2))  in `y'/`y'
   _pctile `var'G , p(9 11   24  26  74 76  89  91 )
   replace ninetyten`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in `y'/`y'
   replace iqr`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in `y'/`y'
   myQuant `var'G ones
   replace ninetyten`var'_Disc=real(r(r4))-real(r(r1)) in `y'/`y'
   replace iqr`var'_Disc=real(r(r3))-real(r(r2))  in `y'/`y'
   sum `var'G [aw=tvs]
   replace sdW`var'=r(sd) in `y'/`y'
   replace counts`var'=r(N) in `y'/`y'
   sum `var'G
   replace sd`var'=r(sd) in `y'/`y'
   drop `var'G
  }
}

forvalues x=17/18 {
   local y=`x'
   gen `var'G=`var' if group2==`x'
   _pctile `var'G [aw=tvs], p(9 11   24  26  74 76  89  91 )
   replace ninetytenW`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in `y'/`y'
   replace iqrW`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in `y'/`y'
   myQuant `var'G tvs
   replace ninetytenW`var'_Disc=real(r(r4))-real(r(r1)) in `y'/`y'
   replace iqrW`var'_Disc=real(r(r3))-real(r(r2))  in `y'/`y'
   _pctile `var'G , p(9 11   24  26  74 76  89  91 )
   replace ninetyten`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in `y'/`y'
   replace iqr`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in `y'/`y'
   myQuant `var'G ones
   replace ninetyten`var'_Disc=real(r(r4))-real(r(r1)) in `y'/`y'
   replace iqr`var'_Disc=real(r(r3))-real(r(r2))  in `y'/`y'
   sum `var'G [aw=tvs]
   replace sdW`var'=r(sd) in `y'/`y'
   replace counts`var'=r(N) in `y'/`y'
   sum `var'G
   replace sd`var'=r(sd) in `y'/`y'
   drop `var'G
}
   
   gen `var'G = `var' if group<=12
   _pctile `var'G [aw=tvs], p(9 11   24  26  74 76  89  91 )
   replace ninetytenW`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in 19/19
   replace iqrW`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in 19/19
   myQuant `var'G tvs
   replace ninetytenW`var'_Disc=real(r(r4))-real(r(r1)) in 19/19
   replace iqrW`var'_Disc=real(r(r3))-real(r(r2))  in 19/19
   _pctile `var'G , p(9 11   24  26  74 76  89  91 )
   replace ninetyten`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in 19/19
   replace iqr`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in 19/19
   myQuant `var'G ones
   replace ninetyten`var'_Disc=real(r(r4))-real(r(r1)) in 19/19
   replace iqr`var'_Disc=real(r(r3))-real(r(r2))  in 19/19
   sum `var'G [aw=tvs]
   replace sdW`var'=r(sd) in 19/19
   replace counts`var'=r(N) in 19/19
   sum `var'G
   replace sd`var'=r(sd) in 19/19
   drop `var'G

   gen `var'G = `var' if group>12 & group<=16
   _pctile `var'G [aw=tvs], p(9 11   24  26  74 76  89  91 )
   replace ninetytenW`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in 20/20
   replace iqrW`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in 20/20
   myQuant `var'G tvs
   replace ninetytenW`var'_Disc=real(r(r4))-real(r(r1)) in 20/20
   replace iqrW`var'_Disc=real(r(r3))-real(r(r2))  in 20/20
   _pctile `var'G , p(9 11   24  26  74 76  89  91 )
   replace ninetyten`var'=1/2*(r(r8)+r(r7)-r(r1)-r(r2)) in 20/20
   replace iqr`var'=1/2*(r(r5)+r(r6)-r(r3)-r(r4))  in 20/20
   myQuant `var'G ones
   replace ninetyten`var'_Disc=real(r(r4))-real(r(r1)) in 20/20
   replace iqr`var'_Disc=real(r(r3))-real(r(r2))  in 20/20
   sum `var'G [aw=tvs]
   replace sdW`var'=r(sd) in 20/20
   replace counts`var'=r(N) in 20/20
   sum `var'G
   replace sd`var'=r(sd) in 20/20
   drop `var'G
  }
}

keep *_Disc sd* counts*
drop sds*
format *_Disc sd* %12.4f
keep in 1/20
drop in 11/11
drop in 10/10
 
forvalues x=1/18 {
   local nt`x'_`xxx'=exp(ninetytenltfpq_Disc[`x']/ninetytenltfpq3_Disc[`x']-1)
   local ntW`x'_`xxx'=exp(ninetytenWltfpq_Disc[`x']/ninetytenWltfpq3_Disc[`x']-1)
   local iqr`x'_`xxx'=exp(iqrltfpq_Disc[`x']/iqrltfpq3_Disc[`x']-1)
   local iqrW`x'_`xxx'=exp(iqrWltfpq_Disc[`x']/iqrWltfpq3_Disc[`x']-1)
   local sd`x'_`xxx'=exp(sdltfpq[`x']/sdltfpq3[`x']-1)
   local sdW`x'_`xxx'=exp(sdWltfpq[`x']/sdWltfpq3[`x']-1)

   local NNt`x'_`xxx'=exp(ninetytenltfpq_Disc[`x']/ninetytenltfpr_Disc[`x']-1)
   local NNtW`x'_`xxx'=exp(ninetytenWltfpq_Disc[`x']/ninetytenWltfpr_Disc[`x']-1)
   local IIqr`x'_`xxx'=exp(iqrltfpq_Disc[`x']/iqrltfpr_Disc[`x']-1)
   local IIqrW`x'_`xxx'=exp(iqrWltfpq_Disc[`x']/iqrWltfpr_Disc[`x']-1)
   local SSd`x'_`xxx'=exp(sdltfpq[`x']/sdltfpr[`x']-1)
   local SSdW`x'_`xxx'=exp(sdWltfpq[`x']/sdWltfpr[`x']-1)

}
}

use temp, replace
forvalues x=1/18 {
   gen nt`x'=.
   gen ntW`x'=.
   gen iqr`x'=.
   gen iqrW`x'=.
   gen sd`x'=.
   gen sdW`x'=.
   qui {
   forvalues xx=1/1000 {
     replace nt`x'=`nt`x'_`xx''  in `xx'/`xx'
     replace ntW`x'=`ntW`x'_`xx''  in `xx'/`xx'
     replace iqr`x'=`iqr`x'_`xx''  in `xx'/`xx'
     replace iqrW`x'=`iqrW`x'_`xx''  in `xx'/`xx'
     replace sd`x'=`sd`x'_`xx''  in `xx'/`xx'
     replace sdW`x'=`sdW`x'_`xx''  in `xx'/`xx'

   }
   }
}

forvalues x=1/18 {
   gen NNt`x'=.
   gen NNtW`x'=.
   gen IIqr`x'=.
   gen IIqrW`x'=.
   gen SSd`x'=.
   gen SSdW`x'=.
   qui {
   forvalues xx=1/1000 {
     replace NNt`x'=`NNt`x'_`xx''  in `xx'/`xx'
     replace NNtW`x'=`NNtW`x'_`xx''  in `xx'/`xx'
     replace IIqr`x'=`IIqr`x'_`xx''  in `xx'/`xx'
     replace IIqrW`x'=`IIqrW`x'_`xx''  in `xx'/`xx'
     replace SSd`x'=`SSd`x'_`xx''  in `xx'/`xx'
     replace SSdW`x'=`SSdW`x'_`xx''  in `xx'/`xx'
    }
  }
}

keep nt1-sdW18 NNt1-SSdW18

foreach var of varlist nt1-sdW18 {
  sort `var' 
  local `var'g1=1/2*(`var'[25]+`var'[26])
  local `var'g5=1/2*(`var'[975]+`var'[976]) 
}

foreach var of varlist NNt1-SSdW18 {
  sort `var' 
  local `var'g1=1/2*(`var'[25]+`var'[26])
  local `var'g5=1/2*(`var'[975]+`var'[976]) 
}

foreach var of varlist nt1-sdW18 {
  qui replace `var'=``var'g1' in 1/1
  qui replace `var'=``var'g5' in 5/5
}

foreach var of varlist NNt1-SSdW18 {
  qui replace `var'=``var'g1' in 1/1
  qui replace `var'=``var'g5' in 5/5
}

keep in 1/5
outsheet using dispersionsCI.csv, replace delim(,)
}

use if ind~=2011 & ind~=2013 & ind~=2084 & ind~=2035 & ind~=2421 using  esumSamp1, replace
keep if group<=12
sort ppn year tfpqOrig
bys ppn year: keep if _n==1

forvalues x=1/4 {
  gen lpp`x'=log(( iam *mnshare2 *(exp(lpriceP))^(1-`x'/5) + (1-iam) + iam*(1-mnshare2) )^(1/(1-`x'/5)))
  bys group year: egen m1=mean(lpp`x')
  replace lpp`x'=lpp`x'-m1
  drop m1
  gen Ltfpq`x'=log(exp(ltfpq)*exp(lpp`x')) 
  bys group year: egen m1=mean(Ltfpq`x')
  replace Ltfpq`x'=Ltfpq`x'-m1
  gen coef`x'=. 
  sum Ltfpq`x' if group<=12 [aw=tvs]
  replace coef`x'=r(sd) in 1/1
  sum Ltfpq`x' if group<=12 
  replace coef`x'=r(sd) in 2/2
  drop m1
}

/* Beginning here, we compute the industry productivity decompositions of Section 3.5.
  The industries that are not taken from esumSamp1 are those from the "Quality-Variation"
  industries , such as wine or softwood cut stock. */

use if ind~=2011 & ind~=2013 & ind~=2084 & ind~=2035 & ind~=2421 using  esumSamp1, replace
sort ppn year tfpqOrig
bys ppn year: keep if _n==1
gen inSamp=(group~=.)

/* To account for the fact that exiting and entering plants are underrepresented in the sample 
 (and thus the effect of net entry on industry productivity growth may be understated), 
  compare entry and exit rates in the benchmark sample to the entry/exit rates from the 
  population */

gen factorEn=.
gen factorEx=.
qui {
forvalues xx=1/12 {
   forvalues yy=1972(5)1997 {
     count if group==`xx' & year==`yy' 
     if r(N)>0 {
        sum ind if group==`xx' & year==`yy' , detail
        local iii=r(p50)
        di `iii'
        sum exit if group==`xx' & year==`yy' [aw=tvsPPNL]
        local t1=r(mean)
        sum exit if ind==`iii' & year==`yy'  [aw=tvsPPNL]
        local t2=r(mean)
        replace factorEx=`t2'/`t1' if group==`xx' & year==`yy' 
        sum entry if group==`xx' & year==`yy' [aw=tvsPPNL]
        local t1=r(mean)   
        sum entry if ind==`iii' & year==`yy' [aw=tvsPPNL]
        local t2=r(mean)
        replace factorEn=`t2'/`t1' if group==`xx' & year==`yy'
   }
  }
}
}

replace factorEn=1 if factorEn==.
replace factorEx=1 if factorEx==.

gen ltfpqOrig=log(tfpqOrig)
gen ltfprOrig=log(tfprOrig)
gen ltfpq3Orig=log(tfpq3Orig)
bys group year: gen fii=1 if _n==1
gen share1=tvsOrig/stvs
gen share2En=share1*factorEn
gen share2Ex=share1*factorEx
bys group year: egen stvs2=sum(tvsOrig)
foreach var of varlist ltfpqOrig ltfprOrig ltfpq3Orig {
  bys group year: egen mean1`var'=sum(`var'*tvsOrig)
  replace mean1`var'=mean1`var'/stvs2
}

foreach var of varlist ltfpqOrig ltfprOrig ltfpq3Orig {
   sort group year
   gen lagmean1`var'=mean1`var'[_n-1] if group==group[_n-1] & year-year[_n-1]==5
   gen leadmean1`var'=mean1`var'[_n+1] if group==group[_n+1] & year-year[_n+1]==-5
   bys group year: egen tempAA=min(lagmean1`var')
   replace lagmean1`var'=tempAA 
   drop tempAA
   bys group year: egen tempAA=min(leadmean1`var')
   replace leadmean1`var'=tempAA 
   drop tempAA
}

foreach var of varlist ltfpqOrig ltfprOrig ltfpq3Orig {
    gen termEnter`var'=entry*share1*(`var'-lagmean1`var')
    gen termExit`var'=-exit*share1*(`var'-mean1`var')
    gen termEnterGR`var'=entry*share1*(`var'-1/2*lagmean1`var'-1/2*mean1`var')
    gen termExitGR`var'=-exit*share1*(`var'-1/2*leadmean1`var'-1/2*mean1`var')
    gen termEnter`var'Fix=entry*share2En*(`var'-lagmean1`var')
    gen termExit`var'Fix=-exit*share2Ex*(`var'-mean1`var')
    gen termEnterGR`var'Fix=entry*share2En*(`var'-1/2*lagmean1`var'-1/2*mean1`var')   
    gen termExitGR`var'Fix=-exit*share2Ex*(`var'-1/2*leadmean1`var'-1/2*mean1`var')
/* Here GR stands for Griliches and Regev (as apposed to the Baily, Hulten, Campbell aggregate productivity decomposition */
}

foreach x in ssEnter ssExit ssEnterGR ssExitGR {
   foreach c in A B C {
     gen `x'`c'= .
     gen `x'`c'Fix=.
  }
}

gen yearC=.
gen groupC=.
gen tvsC=.
local ct=0
gen wt2=.
gen wt3=.
  
sum tvsOrig
local denom=r(sum)

gen growA=.
gen growB=.
gen growC=.

qui {
forvalues yy=1977(5)1997 {
 forvalues x=1/12 {
  local ct=`ct'+1
   count if fii==1 & group==`x'
   local cccc=r(N)
   sum tvsOrig if group==`x' & ((year~=1972 & group~=9) | (group==9 & year~=1992))  
   replace wt2=r(sum)/`denom'/(`cccc'-1) in `ct'/`ct'  
   replace wt3=r(N)/(`cccc'-1) in `ct'/`ct'
   replace yearC=`yy' in `ct'/`ct'
   replace groupC=`x' in `ct'/`ct'
   local yyy=`yy'-5
   count if group==`x' & year==`yy' & termEnterltfpqOrig~=. 
   if r(N)>0 {

      qui sum mean1ltfprOrig if group==`x' & year==`yy'
      local rr1=r(mean)
      qui sum mean1ltfprOrig if group==`x' & year==`yyy'
      local rr2=r(mean)
      replace growA=100*(`rr1'-`rr2') in  `ct'/`ct'
      qui sum mean1ltfpqOrig if group==`x' & year==`yy'
      local rr1=r(mean)
      qui sum mean1ltfpqOrig if group==`x' & year==`yyy'
      local rr2=r(mean)
      replace growB=100*(`rr1'-`rr2') in  `ct'/`ct'
      qui sum mean1ltfpq3Orig if group==`x' & year==`yy'
      local rr1=r(mean)
      qui sum mean1ltfpq3Orig if group==`x' & year==`yyy'
      local rr2=r(mean)
      replace growC=100*(`rr1'-`rr2') in  `ct'/`ct'

      qui sum tvsOrig if group==`x' & year==`yy'
      replace tvsC=r(sum) in `ct'/`ct'
      sum termEnterltfprOrig if group==`x' & year==`yy'
      replace ssEnterA=r(sum)*100 in `ct'/`ct'
      sum termEnterltfpqOrig if group==`x' & year==`yy'
      replace ssEnterB=r(sum)*100 in `ct'/`ct'
      sum termEnterltfpq3Orig if group==`x' & year==`yy'
      replace ssEnterC=r(sum)*100 in `ct'/`ct'

      sum termEnterGRltfprOrig if group==`x' & year==`yy'
      replace ssEnterGRA=r(sum)*100 in `ct'/`ct'
      sum termEnterGRltfpqOrig if group==`x' & year==`yy' 
      replace ssEnterGRB=r(sum)*100 in `ct'/`ct'
      sum termEnterGRltfpq3Orig if group==`x' & year==`yy'
      replace ssEnterGRC=r(sum)*100 in `ct'/`ct' 

      sum termEnterltfprOrigFix if group==`x' & year==`yy'
      replace ssEnterAFix=r(sum)*100 in `ct'/`ct'
      sum termEnterltfpqOrigFix if group==`x' & year==`yy'
      replace ssEnterBFix=r(sum)*100 in `ct'/`ct'
      sum termEnterltfpq3OrigFix if group==`x' & year==`yy'
      replace ssEnterCFix=r(sum)*100 in `ct'/`ct'

      sum termEnterGRltfprOrigFix if group==`x' & year==`yy'
      replace ssEnterGRAFix=r(sum)*100 in `ct'/`ct'
      sum termEnterGRltfpqOrigFix if group==`x' & year==`yy' 
      replace ssEnterGRBFix=r(sum)*100 in `ct'/`ct'
      sum termEnterGRltfpq3OrigFix if group==`x' & year==`yy'
      replace ssEnterGRCFix=r(sum)*100 in `ct'/`ct' 
   }

   count if group==`x' & year==`yyy' & termExitltfpqOrig~=. 
   if r(N)>0 & ((`x'~=3 & `x'~=5) | `yy'~=1992) {
      sum termExitltfprOrigFix if group==`x' & year==`yyy'
      replace ssExitAFix=r(sum)*100 in `ct'/`ct'
      sum termExitltfpqOrigFix if group==`x' & year==`yyy'
      replace ssExitBFix=r(sum)*100 in `ct'/`ct'
      sum termExitltfpq3OrigFix if group==`x' & year==`yyy'
      replace ssExitCFix=r(sum)*100 in `ct'/`ct'

      sum termExitGRltfprOrigFix if group==`x' & year==`yyy'
      replace ssExitGRAFix=r(sum)*100 in `ct'/`ct'
      sum termExitGRltfpqOrigFix if group==`x' & year==`yyy' 
      replace ssExitGRBFix=r(sum)*100 in `ct'/`ct'
      sum termExitGRltfpq3OrigFix if group==`x' & year==`yyy'
      replace ssExitGRCFix=r(sum)*100 in `ct'/`ct' 

      sum termExitltfprOrig if group==`x' & year==`yyy'
      replace ssExitA=r(sum)*100 in `ct'/`ct'
      sum termExitltfpqOrig if group==`x' & year==`yyy'
      replace ssExitB=r(sum)*100 in `ct'/`ct'
      sum termExitltfpq3Orig if group==`x' & year==`yyy'
      replace ssExitC=r(sum)*100 in `ct'/`ct'

      sum termExitGRltfprOrig if group==`x' & year==`yyy'
      replace ssExitGRA=r(sum)*100 in `ct'/`ct'
      sum termExitGRltfpqOrig if group==`x' & year==`yyy' 
      replace ssExitGRB=r(sum)*100 in `ct'/`ct'
      sum termExitGRltfpq3Orig if group==`x' & year==`yyy'
      replace ssExitGRC=r(sum)*100 in `ct'/`ct' 
   }
}
}
}

local count=0
foreach var of varlist growA ssEnterA ssEnterB ssEnterC ssExitA ssExitB ssExitC ssEnterGRA ssEnterGRB ssEnterGRC ssExitGRA ssExitGRB ssExitGRC {
   local count=`count'+1
   gen Coef`count'=.
   qui sum `var' [aw=wt2]
   replace Coef`count'=r(mean) in 1/1
   qui sum `var' [aw=wt3]
   replace Coef`count'=r(mean) in 2/2
   if `count'>1 {
      qui sum `var'Fix [aw=wt2]
      replace Coef`count'=r(mean) in 3/3
      qui sum `var'Fix [aw=wt3]
      replace Coef`count'=r(mean) in 4/4
   }
}

keep Coef*
keep in 1/4
gen measure=_n
outsheet using AggDecomposition.csv, replace  delim(,)

/* What would happen if the elasticity of substitution between "priced" materials and other 
  inputs was allowed to be less than 1, as is presumed in the remainder of the paper ?   */

use if ind~=2011 & ind~=2013 & ind~=2084 & ind~=2035 & ind~=2421 using  esumSamp1, replace
keep if group<=12
sort ppn year tfpqOrig
bys ppn year: keep if _n==1

forvalues x=1/4 {
  gen lpp`x'=log(( iam *mnshare2* (exp(lpriceP))^(1-`x'/5) + (1-iam) + iam*(1-mnshare2) )^(1/(1-`x'/5)))
  bys group year: egen m1=mean(lpp`x')
  replace lpp`x'=lpp`x'-m1
  drop m1
  gen Ltfpq`x'=log(exp(ltfpq)*exp(lpp`x'))
  bys group year: egen m1=mean(Ltfpq`x')
  replace Ltfpq`x'=Ltfpq`x'-m1
  drop m1
  gen coef`x'=. 
  sum Ltfpq`x' if group<=12 [aw=tvs]
  replace coef`x'=r(sd) in 1/1
  sum Ltfpq`x' if group<=12 
  replace coef`x'=r(sd) in 2/2
}
keep coef*
outsheet using elasticityCheck.csv, delim(,) replace

}  /* END OF SKIP */

/* Here, I perform the calculations of Section 4.3 of the paper */

use ../../data/zipcodes, replace
sort zipcode
drop if longit==0 | latit==0
by zipcode: keep if _n==1
keep zipcode longit latit
save zipcodes, replace

insheet using persist.csv, clear
bys lbdnum year: gen fi=1 if _n==1
by lbdnum : egen z=sum(fi)
keep if z==2
drop z fi
gen group=1 if stcc==32411 | stcc==31100
replace group=2 if group==.
gen val=vs*cfs_wgt
collapse (sum) val (count) ships=cfs_wgt (min) firmid emp orig_zip , by(lbdnum dest_zip year group) 
reshape wide val emp firmid ships orig_zip  , i(lbdnum dest_zip group) j(year)
sum orig_zip*
drop orig_zip1992
save temp, replace
forvalues xx=1/2 {
  use temp, replace
  keep if group==`xx'
  fillin lbdnum dest_zip
  gen ship=(val1997>0 & val1997<.)
  gen ship93=(val1992>0 & val1992<.)
    replace ship=0 if ship==.
  replace ship93=0 if ship93==.
  bys dest_zip: egen z=max(ship)
  keep if z==1
  drop z

/* For the small number of plants that report different zip codes (or firm identifiers or employment) in different CFS 
  shipments, take the mode value of the variable */

  foreach var of varlist orig_zip* firmid* emp* {
    bys lbdnum: egen m`var'=mode(`var'), minmode
    replace `var'=m`var'
    drop m`var' 
  }

  ren dest_zip zipcode
  merge n:1 zipcode using zipcodes
  ren zipcode dest_zip
  ren longit dest_longit
  ren latit dest_latit
  drop if _merge==2
  drop _merge
  ren orig_zip zipcode
  merge n:1 zipcode using zipcodes
  ren zipcode orig_zip
  ren longit orig_longit
  ren latit orig_latit
  drop if _merge==2
  drop _merge
  bys dest_zip: egen z=max(ship)
  keep if z==1
  drop z
  xtset dest_zip
  foreach var of varlist *longit  { 
    drop if `var'==.
  }
  drop if firmid1992==. | firmid1997==.
  merge n:1 firmid1997 dest_zip using firmlocs
  drop if _merge==2
  ren _merge firmD
  replace firmD=(firmD-1)/2
  bys firmid1997 ship93 ship: gen fix=1 if _n==1
  by firmid1997: egen zz=sum(fix)
  keep if zz==4       /* See footnote 45.  I have to drop these observations to conform with Census' disclosure requirements.   */
  drop zz fix
  bys lbdnum: gen id=1 if _n==1
  replace id=sum(id) 
  save esumPersist`xx', replace
  gen lmileage=log(sqrt( 69.31^2 * (dest_latit-orig_latit)^2 + 53.0^2 * (dest_longit-orig_longit)^2))    /* Again, this is a formula for the great circle distance bewtween two points */
  qui replace lmileage=-3 if lmileage==.   /* For a small number of cases, the distance between two points is reported as 0 (and so log mileage comes up as missing).  Fill these values in with an arbitrary small number*/
  gen coef1=.
  gen coef2=. 
  gen coef3=.
  sum ship
  replace coef1=r(mean) in 1/1
  if `persist'==1 {
  qui xtlogit ship lmileage i.id, fe 
  replace coef1=_b[lmileage] in 3/3
  replace coef1=_se[lmileage] in 4/4
  replace coef1=e(N)  in 5/5
  replace coef1=e(N_g) in 6/6
  replace coef1=e(r2_p) in 7/7
  qui xtlogit ship ship93 lmileage i.id, fe
  replace coef2=_b[ship93] in 1/1
  replace coef2=_se[ship93] in 2/2
  replace coef2=_b[lmileage] in 3/3
  replace coef2=_se[lmileage] in 4/4
  replace coef2=e(N)  in 5/5
  replace coef2=e(N_g) in 6/6
  replace coef2=e(r2_p) in 7/7
  qui xtlogit ship ship93 lmileage i.id firmD,  fe
  replace coef3=_b[ship93] in 1/1
  replace coef3=_se[ship93] in 2/2
  replace coef3=_b[lmileage] in 3/3
  replace coef3=_se[lmileage] in 4/4
  replace coef3=e(N)  in 5/5
  replace coef3=e(N_g) in 6/6
  replace coef3=e(r2_p) in 7/7
  keep coef1 coef2 coef3
  keep if _n<=7 
  outsheet using persistRegs_`xx'.csv, replace delim(,)
}
}

if `plocal'==1 {
  local command1 "if stcc==32411 & year==1992 using cfsFull"
  local command2 "if stcc==26311 & year==1992 using cfsFull"
  local command3 "if (stcc==27319 | stcc==27320 ) & year==1997 using cfsFull"
  forvalues x=1/3 {
   use `command`x'' , replace
   gen tonmileprice=.025*(mode==4)+.131*(mode~=4)
   ren vs value
   if `x'==3 {
     replace tonmileprice=.024*(mode==4)+.143*(mode~=4) if year==1997  /* These numbers come from the Bureau of Transportation Statistics */
   }
   gen shipcost=weight/2000*mileage*tonmileprice
   drop mileage
   replace value=value+shipcost
   gen price=value/weight
   bys dest_zip: egen vs=sum(value)
   bys dest_zip: egen wei=sum(weight)
   collapse (min) vs wei (mean) price [aw=weight] , by(dest_zip)
   ren dest_zip zipcode
   merge n:1 zipcode using zipcodes
   ipolate latitude zipcode, gen(lat2)
   ipolate longitude zipcode, gen(long2)
   replace latitude=lat2 if latitude==.
   replace longitude=long2 if longitude==.
   drop if _merge==2
   drop _merge lat2 long2
   save tempT, replace
   foreach var of varlist * {
      ren `var' `var'O 
   }
   cross using tempT
   drop if zipcode==zipcodeO
   gen mileage=sqrt( 69.31^2 * (latitudeO-latitude)^2 + 53.0^2 * (longitudeO-longitude)^2) 
   drop if mileage>150 
   gen price150=priceO
   gen price100=priceO if mileage<100
   gen price50=priceO if mileage<50
   gen price20=priceO if mileage<20
   collapse (mean) price100 price20 price150 price50 price [aw=vsO] , by(zipcode)
   ren zipcode dest_zip
   save priceO_`x', replace
  }
  use priceO_2, replace
  gen year=1992
  append using priceO_3
  replace year=1997 if year==.
  save priceO_Box, replace
  use priceO_1, replace
  save priceO_NoBox, replace
}

/* Finally, get information on within-plant differences in output prices 
versus across-plant differences in output prices */ 

use esumNoBox, replace
drop *f ppc
append using esumBox
keep if todrop0_2_2==0
keep lbdnum year
sort lbdnum year
by lbdnum year : keep if _n==1
save t1, replace

insheet using persist.csv, clear
/* Aggregate over by cfn X year X destination zip_code */
gen val=vs
gen wei=weight
bys cfn dest_zip year: gen ships=_N
gen group=(stcc>30000)
gen price=log(val/wei)
gen todrop=0
sum price if group==0 & year==1992 [aw=wei]
replace todrop=1 if (abs(price-r(mean))>`outlie2') &  group==0 & year==1992
sum price if group==1 & year==1992 [aw=wei]
replace todrop=1 if (abs(price-r(mean))>`outlie2') &  group==1 & year==1992
sum price if group==0 & year==1997 [aw=wei]
replace todrop=1 if (abs(price-r(mean))>`outlie2') &  group==0 & year==1997
sum price if group==1 & year==1997 [aw=wei]
replace todrop=1 if (abs(price-r(mean))>`outlie2') &  group==1 & year==1997

drop if todrop==1 
drop stcc price todrop

collapse  (sum) val cfs_wgt wei (min) ltfpq priceout group ships lbdnum firmid mileage orig_zip emp, by(cfn dest_zip year)

gen price=log(val/wei)
replace priceout=log(priceout)
sort lbdnum year
by lbdnum year: egen s1=sum(val)
by lbdnum year: egen s2=sum(wei)
by lbdnum year: gen fi=1 if _n==1

merge n:1 lbdnum year using t1
keep if _merge==3
drop _merge
gen priceMn=log(s1/s2)
bys lbdnum year: egen sdP=sd(price)
ren s1 totalval
ren s2 totalwei
gen dev=price-priceMn
bys group year : egen s3=sum(priceMn*fi*totalwei)
bys group year : egen s3a=sum(priceout*fi*totalwei)
bys group year : egen s4=sum(price*wei)
by group year: egen s5=sum(fi*totalwei)
by group year: egen s6=sum(wei)
replace priceMn=priceMn-s3/s5
replace priceout=priceout-s3a/s5
replace price=price-s4/s6
drop s3 s4 s5 s6

save esumPapCem2, replace

/* Beginning here, I construct the plots for the two figures that actually appear in the paper (the one in Section 4.2, and the one 
  in Appendix A.12 */

gen xvar=-1+_n/400 
replace xvar=. if xvar>1
kdensity priceMn if group==1 & abs(priceMn)<1  [aw=wei], nograph gen(xvar1_1 yvar1_1) at(xvar)
kdensity dev if group==1 & abs(dev)<1  [aw=wei], nograph gen(xvar1_2 yvar1_2) at(xvar)
kdensity price if group==1 & abs(price)<1  [aw=wei], nograph gen(xvar1_3 yvar1_3) at(xvar)

kdensity priceMn if group==0 & year<=1993 & abs(priceMn)<1  [aw=wei], nograph gen(xvar2_1 yvar2_1) at(xvar)
kdensity dev if group==0 & year<=1993 & abs(dev)<1  [aw=wei], nograph gen(xvar2_2 yvar2_2) at(xvar)
kdensity price if group==0 & year<=1993 & abs(price)<1  [aw=wei], nograph gen(xvar2_3 yvar2_3) at(xvar)

kdensity priceMn if group==0 & year>1993 & abs(priceMn)<1  [aw=wei], nograph gen(xvar3_1 yvar3_1) at(xvar)
kdensity dev if group==0 & year>1993 & abs(dev)<1  [aw=wei], nograph gen(xvar3_2 yvar3_2) at(xvar)
kdensity price if group==0 & year>1993 & abs(price)<1  [aw=wei], nograph gen(xvar3_3 yvar3_3) at(xvar)

kdensity priceMn if  abs(priceMn)<1  [aw=wei], nograph gen(xvar4_1 yvar4_1) at(xvar)
kdensity dev if  abs(dev)<1  [aw=wei], nograph gen(xvar4_2 yvar4_2) at(xvar)
kdensity price if  abs(price)<1  [aw=wei], nograph gen(xvar4_3 yvar4_3) at(xvar)

graph twoway (line yvar1_1 xvar , color(black) lpattern("--") lwidth(medthick)) (line yvar1_2 xvar, color(black) lpattern("_.") lwidth(thick)) (line yvar1_3 xvar , color(black)),  xtitle("Relative Price") ytitle("Density") legend(r(1) lab(1 "Across Supplier") lab(2 "Within Supplier") lab(3 "Overall")) 
graph export "rel_price_Cement_BW.eps", replace

graph twoway (line yvar2_1 xvar , color(black) lpattern("--") lwidth(medthick)) (line yvar2_2 xvar, color(black) lpattern("_.") lwidth(thick)) (line yvar2_3 xvar , color(black)),  xtitle("Relative Price") ytitle("Density") legend(r(1) lab(1 "Across Supplier") lab(2 "Within Supplier") lab(3 "Overall")) 
graph export "rel_price_Paperboard_BW_1992.eps", replace

graph twoway (line yvar3_1 xvar , color(black) lpattern("--") lwidth(medthick)) (line yvar3_2 xvar, color(black) lpattern("_.") lwidth(thick)) (line yvar3_3 xvar , color(black)),  xtitle("Relative Price") ytitle("Density") legend(r(1) lab(1 "Across Supplier") lab(2 "Within Supplier") lab(3 "Overall")) 
graph export "rel_price_Paperboard_BW_1997.eps", replace

graph twoway (line yvar4_1 xvar , color(black) lpattern("--") lwidth(medthick)) (line yvar4_2 xvar, color(black) lpattern("_.") lwidth(thick)) (line yvar4_3 xvar , color(black)),  xtitle("Relative Price") ytitle("Density") legend(r(1) lab(1 "Across Supplier") lab(2 "Within Supplier") lab(3 "Overall")) 
graph export "rel_price_Pooled_BW.eps", replace

gen statsC=.
gen statsB=.
gen statsP=.
qui {
sum priceMn if group==0 & fi==1 [aw=totalwei]
replace statsB=r(sd) in 1/1
sum priceMn if group==1 & fi==1 [aw=totalwei]
replace statsC=r(sd) in 1/1
sum priceMn if fi==1 [aw=totalwei]   
replace statsP=r(sd) in 1/1
sum priceout if group==0 & fi==1 [aw=totalwei]
replace statsB=r(sd) in 2/2
sum priceout if group==1 & fi==1 [aw=totalwei]
replace statsC=r(sd) in 2/2
sum priceout if fi==1 [aw=totalwei]
replace statsP=r(sd) in 2/2
cor priceout priceMn if group==0 & fi==1 [aw=totalwei]
replace statsB=r(rho) in 3/3
replace statsB=r(N) in 4/4
cor priceout priceMn if group==1 & fi==1 [aw=totalwei]
replace statsC=r(rho) in 3/3
replace statsC=r(N) in 4/4
cor priceout priceMn if fi==1 [aw=totalwei]
replace statsP=r(rho) in 3/3
replace statsP=r(N) in 4/4
sum price if group==0 [aw=wei]
replace statsB=r(sd) in 5/5
replace statsB=r(N) in 6/6
sum price if group==1 [aw=wei]
replace statsC=r(sd) in 5/5
replace statsC=r(N) in 6/6
sum price [aw=wei]
replace statsP=r(sd) in 5/5
replace statsP=r(N) in 6/6
sum dev if group==0 [aw=wei]
replace statsB=r(sd) in 7/7
sum dev if group==1 [aw=wei]
replace statsC=r(sd) in 7/7
sum dev  [aw=wei]
replace statsP=r(sd) in 7/7
reg price priceMn if group==0 [aw=wei]
replace statsB=_b[priceMn] in 8/8
replace statsB=_se[priceMn] in 9/9
replace statsB=e(r2_a) in 10/10
reg price priceMn if group==1 [aw=wei]
replace statsC=_b[priceMn] in 8/8
replace statsC=_se[priceMn] in 9/9
replace statsC=e(r2_a) in 10/10
reg price priceMn [aw=wei]
replace statsP=_b[priceMn] in 8/8
replace statsP=_se[priceMn] in 9/9
replace statsP=e(r2_a) in 10/10
cor priceout priceMn if group==0 & fi==1 
replace statsB=r(rho) in 11/11
cor priceout priceMn if group==1 & fi==1 
replace statsC=r(rho) in 11/11
cor priceout priceMn if fi==1 
replace statsP=r(rho) in 11/11
spearman priceout priceMn if group==0 & fi==1 
replace statsB=r(rho) in 12/12
spearman priceout priceMn if group==1 & fi==1 
replace statsC=r(rho) in 12/12
spearman priceout priceMn if fi==1 
replace statsP=r(rho) in 12/12

}
keep in 1/12
keep stats*
outsheet using deviations.csv, delim(,) replace 

/* Regression of profits on input prices, per the referee's suggestion */

use if group<=12 using esumSamp1, replace
gen lprofits=log(tvs-cm-sw-bae*strkl-mae*eqrkl)
bys group year: egen mnprofits=mean(lprofits)
replace lprofits=lprofits-mnprofits
gen result=.
reg lprofits lpriceP
replace result=_b[lpriceP] in 1/1
replace result=_se[lpriceP] in 2/2
reg lprofits lpriceP [aw=tvs]
replace result=_b[lpriceP] in 3/3
replace result=_se[lpriceP] in 4/4
cor lprofits lpriceP 
replace result=r(rho) in 5/5
cor lprofits lpriceP [aw=tvs]
replace result=r(rho) in 6/6
keep result
keep in 1/6
outsheet using profitsOnprice.csv, replace delim(,)

use esumSamp1, replace
keep if group==9
sort lbdnum year ltfpq3
by lbdnum year: keep if _n==1
ren lbdnum lbdnumd
keep lbdnumd ltfpq3 year
save tempBox, replace

insheet using boxesCFS.csv, clear
bys rec_num year: gen count=_N
keep if stcc==26311 | stcc==27319 | stcc==27320  /* These are the materials codes (according to the CFS) of 
                                                    paperboard (26311 is for 1993, the others are for 1997 */
keep if group==1 |  group==3                     /* Keep only two of the "groups" of upstream plants */
sort lbdnumd year
merge n:1 lbdnumd year using boxesSamp          
drop if _merge==1                               /* Keep only plants that are in the main sample */
drop _merge

if `priceCheck'==1 {
  gen price=log(vs/weight)
  gen todrop=0
  sum price if  year<1995 [aw=weight]
  replace todrop=1 if (abs(price-r(mean))>`outlie2') & year<1995
  sum price if  year>1995 [aw=weight]
  replace todrop=1 if (abs(price-r(mean))>`outlie2') & year>1995
  drop if todrop==1
  drop price todrop
}
save boxesCFS, replace 
use boxesCFS, replace
keep if ltfpq~=.

/* Normalize TFPQ of upstream establishments, by year-group */

bys lbdnum year: gen fiU=1 if _n==1
forvalues yr=1992(5)1997 {
   forvalues gro==1(2)3 {
    qui sum ltfpq if group==`gro' & year==`yr' & fiU==1 [aw=tvs] , detail 
    qui replace ltfpq=ltfpq-r(mean) if group==`gro' & year==`yr' 
  }
}

/* Create relative (within sending plant) f.o.b. prices) */

gen same=(firmid==firmidd)   /* Is the firmid of the buyer and supplier the same? */
bys rec_num: egen mxsame=max(same)

bys lbdnum year rec_num: gen fix=1 if _n==1
bys lbdnum year: egen s1=sum(vs*cfs_wgt)
by  lbdnum year: egen s2=sum(weight*cfs_wgt)
gen plantUpPr=log(s1/s2)
gen relpriceMean=log(vs/weight)-plantUpPr   /* I used to calculate the supplier-deviation relative to only the matched shipments */
replace relpriceMean=log(vs/weight)-log(vss/weights)   /* Now, though, I compute the supplier deviation relative to all of the shipments made by the supplier in the CFS */
drop s1 s2 fix
if `residRelPrice'==1 {
  gen lmileage=log(mileage)
  forvalues x=2/5 {
    gen lmileage`x'=lmileage^(`x') 
  }
  reg relpriceMean lmileage-lmileage5
  predict relpriceResid, resid
  replace relpriceMean=relpriceResid
}

/* These shipping rates were pulled from the Bureau of Transportation Statitics website.
   mode=4 corresponds to rail transport. */

gen tonmileprice=.025*(mode==4)+.131*(mode~=4)
replace tonmileprice=.024*(mode==4)+.143*(mode~=4) if year==1997
gen shipcost=weight/2000*mileage*tonmileprice  /* Weight is stated differently in the CFS and in the CM */

drop if mxsame==1 & same==0 /*  Drop observations for which a candidate downstream plant is 
                                not in the same firm as the upstream plant, but there exists some other 
                                plant in the zip code that *is* in the same firm as the upstream plant.   
                              (in other words, similar to Atalay, Hortacsu and Syverson, I assume that a shipment 
                              goes stays within the firm, if there is, indeed, a candidate plant in the downstream
                              zip code ) */ 
gen priceO=log(priceout)
gen priceI=log(mc/mqdc)
bys lbdnumd year: gen fiD=1 if _n==1
by lbdnumd year: egen denom=sum(weight*(1-same)/2)
by lbdnumd year: egen numer=sum((vs+shipcost*`shipCost')*(1-same))
by lbdnumd year: egen s1=sum(vs+shipcost*`shipCost')
by lbdnumd year: egen s2=sum((vs+shipcost*`shipCost')*(1-same))
gen fracsame=1-s2/s1 
gen priceI_CFS=log(numer/denom)
drop numer denom
by lbdnumd year: egen denom=sum(vs*(1-same))
by lbdnumd year: egen numer=sum(exp(ltfpq)*vs*(1-same))
gen tfpq_Up_W=log(numer/denom)
drop numer denom
by lbdnumd year: egen denom=sum(1-same)
by lbdnumd year: egen numer=sum(exp(ltfpq)*(1-same))
gen tfpq_Up_UW=log(numer/denom)
drop numer denom


/* Compute the average "markup" that the upstream plant faces */

by lbdnumd year: egen denom=sum(1-same)
by lbdnumd year: egen numer=sum(relpriceMean*(1-same))
by lbdnumd year: egen numer1=sum((qtr==1)*vs*(1-same))
by lbdnumd year: egen numer2=sum((qtr==2)*vs*(1-same))
by lbdnumd year: egen numer3=sum((qtr==3)*vs*(1-same))
by lbdnumd year: egen numer4=sum((qtr==4)*vs*(1-same))
by lbdnumd year: egen numer5=sum(vs*(1-same))
forvalues x=1/4 {
   gen qtrFrac`x'=numer`x'/numer5
}
gen avgsizeOfCust=log(numer5)
gen avgsizeOfShip=log(numer5/denom)
gen avgMarkupMean=numer/denom
drop numer denom

gen matchprice0=1
gen matchprice1=(abs(priceI-priceI_CFS)<.8)   
gen matchprice2=(abs(priceI-priceI_CFS)<.4)
keep if ltfpqd~=. 
forvalues ii=1/2 { 
  forvalues jj=1/3 {
  gen todrop0_`ii'_`jj'=0
  gen todrop1_`ii'_`jj'=0 
  gen todrop2_`ii'_`jj'=0
 }
}

gen fracTest_1=0.05  /* i.e., drop the plant if the plant purchases (according to the CFS) more than 5% of the material 
                       from within the firm */
gen fracTest_2=0.15
gen fracTest_3=0.25

gen countTest_1=2  /* i.e., drop the plant if there are more than 2 "candidate" plants in the zip code of the plant */
gen countTest_2=.

forvalues ii=1/2 {
 forvalues jj=1/3 {
  forvalues yr=1992(5)1997 {
   forvalues gro==8/9 { 
    forvalues x=0/2 {
    qui sum ltfpqd if groupd==`gro' & year==`yr' & fiD==1 & matchprice`x'==1 & fracsame<=fracTest_`jj' , detail 
    qui replace todrop`x'_`ii'_`jj'=1 if ( abs(ltfpqd-r(mean))>`outlie' ) & groupd==`gro' & year==`yr' & fiD==1 & matchprice`x'==1 & fracsame<=fracTest_`jj' 
    qui  sum tfpq_Up_W if groupd==`gro' & year==`yr' & fiD==1 & matchprice`x'==1 & fracsame<=fracTest_`jj' , detail 
    qui replace todrop`x'_`ii'_`jj'=1 if ( abs(tfpq_Up_W-r(mean))>`outlie') & groupd==`gro' & year==`yr' & fiD==1 & matchprice`x'==1 & fracsame<=fracTest_`jj' 
    qui replace todrop`x'_`ii'_`jj'=1 if count>countTest_`ii'
    qui replace todrop`x'_`ii'_`jj'=1 if fracsame>=fracTest_`jj'
    bys lbdnumd year: egen t=max(todrop`x'_`ii'_`jj')
    replace todrop`x'_`ii'_`jj'=t
    drop t
   } 
  }
}
}
}

merge n:1 lbdnumd year using tempBox
keep if _merge==3
drop _merge
merge n:1 dest_zip year using priceO_Box
drop if _merge==2
drop _merge
save sampleBox, replace
replace price50=log(price50)
replace price100=log(price100)
replace price150=log(price150)
replace price100=price150 if price100==.
replace price50=price100 if price50==.
forvalues ii=1/2 {
 forvalues jj=1/3 {
  forvalues x=0/2 {
  gen ltfpqd_`x'_`ii'_`jj'=.
  gen ltfpq3_`x'_`ii'_`jj'=.
  gen tfpq_Up_W_`x'_`ii'_`jj'=.
  gen priceI_CFS_`x'_`ii'_`jj'=.
  gen priceI_`x'_`ii'_`jj'=.
  gen ltfpqd_`x'_`ii'_`jj'_W=.
  gen ltfpq3_`x'_`ii'_`jj'_W=.
  gen tfpq_Up_W_`x'_`ii'_`jj'_W=.
  gen priceI_CFS_`x'_`ii'_`jj'_W=.
  gen priceI_`x'_`ii'_`jj'_W=.
  forvalues xxx=50(50)150 {
     gen price`xxx'_`x'_`ii'_`jj'_W=.
     gen price`xxx'_`x'_`ii'_`jj'=.
  }
  forvalues yr=1992(5)1997 {
   forvalues gro==8/9 { 
    qui sum price50 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace price50_`x'_`ii'_`jj'=price50-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price100 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace price100_`x'_`ii'_`jj'=price100-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price150 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace price150_`x'_`ii'_`jj'=price150-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum ltfpqd if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace ltfpqd_`x'_`ii'_`jj'=ltfpqd-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum ltfpq3 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace ltfpq3_`x'_`ii'_`jj'=ltfpq3-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum tfpq_Up_W if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace tfpq_Up_W_`x'_`ii'_`jj'=tfpq_Up_W-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum priceI_CFS if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui replace priceI_CFS_`x'_`ii'_`jj'=priceI_CFS-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum priceI if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui replace priceI_`x'_`ii'_`jj'=priceI-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1

    qui sum ltfpqd if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace ltfpqd_`x'_`ii'_`jj'_W=ltfpqd-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum tfpq_Up_W if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace tfpq_Up_W_`x'_`ii'_`jj'_W=tfpq_Up_W-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum priceI_CFS if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd] 
    qui replace priceI_CFS_`x'_`ii'_`jj'_W=priceI_CFS-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj' & matchprice`x'==1
    qui sum priceI if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd] 
    qui replace priceI_`x'_`ii'_`jj'_W=priceI-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj' & matchprice`x'==1
    qui sum ltfpq3 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1  [aw=tvsd]
    qui replace ltfpq3_`x'_`ii'_`jj'_W=ltfpq3-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price50 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace price50_`x'_`ii'_`jj'_W=price50-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price100 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace price100_`x'_`ii'_`jj'_W=price100-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price150 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace price150_`x'_`ii'_`jj'_W=price150-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1

   } 
  }
}
}
}

save esumBox, replace
if `runRegs'==1 {
 do runRegs_rev 
 format price_* tfp_* phi_* divO* disp* mn_d* sd_d* %12.4f
 gen sample="Boxes"
 keep price_* tfp_* phi_* sample* divO*  disp* iii jjj ddd xxx kkk mn_d* sd_d* ppp
 save boxRegResults, replace
}
use esumSamp1, replace
gen fiU=.
keep in 1/500
keep fiU
save emptyDset, replace

insheet using cementCFS.csv, clear
bys rec_num : gen count=_N
keep if stcc==32411

merge n:1 lbdnumd using concreteSamp
drop if _merge==1
drop _merge
if `priceCheck'==1 {
  gen price=log(vs/weight)
  gen todrop=0
  sum price if  year<1995 [aw=weight]
  replace todrop=1 if (abs(price-r(mean))>`outlie2') & year<1995
  sum price if  year>1995 [aw=weight]
  replace todrop=1 if (abs(price-r(mean))>`outlie2') & year>1995 
  drop if todrop==1
  drop price todrop
}
save cementCFS, replace 
use cementCFS, replace
replace vs=vs/1.1  if year<1997  /* Price index */
keep if ltfpq~=.

/* Normalize TFPQ of upstream guys, by year group */

bys lbdnum : gen fiU=1 if _n==1
forvalues gro==1/2 {
    qui sum ltfpq if group==`gro'  & fiU==1 [aw=tvs] , detail 
    qui replace ltfpq=ltfpq-r(mean) if group==`gro'  
}

/* Create relative (within sending plant) f.o.b. prices) */

bys lbdnum year rec_num: gen fix=1 if _n==1
bys lbdnum year: egen s1=sum(vs*cfs_wgt)
by  lbdnum year: egen s2=sum(weight*cfs_wgt)
gen plantUpPr=log(s1/s2)
gen relpriceMean=log(vs/weight)-plantUpPr
replace relpriceMean=log(vs/weight)-log(vss/weights)
drop s1 s2 fix
if `residRelPrice'==1 {
  gen lmileage=log(mileage)
  forvalues x=2/5 {
    gen lmileage`x'=lmileage^(`x') 
  }
  reg relpriceMean lmileage-lmileage5
  predict relpriceResid, resid
  replace relpriceMean=relpriceResid
}

gen same=(firmid==firmidd)
bys rec_num: egen mxsame=max(same)
drop if mxsame==1 & same==0  
gen priceO=log(priceout)
gen priceI=log(mc/mqdc)
bys lbdnumd : gen fiD=1 if _n==1

gen tonmileprice=.025*(mode==4)+.131*(mode~=4)   /* These numbers are different shipping rates (not from Census data) for different 
                                                         shipment methods */
replace tonmileprice=.024*(mode==4)+.143*(mode~=4) if year==1997
gen shipcost=weight/2000*mileage*tonmileprice

by lbdnumd : egen denom=sum(weight*(1-same)/2)  
by lbdnumd : egen numer=sum((vs+shipcost*`shipCost'/1.1)*(1-same))
by lbdnumd : egen s1=sum(vs+shipcost*`shipCost'/1.1)
by lbdnumd : egen s2=sum((vs+shipcost*`shipCost'/1.1)*(1-same))
gen fracsame=1-s2/s1 
gen priceI_CFS=log(numer/denom)
drop numer denom
by lbdnumd : egen denom=sum(vs*(1-same))
by lbdnumd : egen numer=sum(exp(ltfpq)*vs*(1-same))
gen tfpq_Up_W=log(numer/denom)
drop numer denom
by lbdnumd : egen denom=sum(1-same)
by lbdnumd : egen numer=sum(exp(ltfpq)*(1-same))
gen tfpq_Up_UW=log(numer/denom)
drop numer denom

/* Compute the average "markup" that the upstream plant faces */

by lbdnumd: egen denom=sum(1-same)
by lbdnumd: egen numer=sum(relpriceMean*(1-same))
by lbdnumd: egen numer1=sum((qtr==1)*vs*(1-same))
by lbdnumd: egen numer2=sum((qtr==2)*vs*(1-same))
by lbdnumd: egen numer3=sum((qtr==3)*vs*(1-same))
by lbdnumd: egen numer4=sum((qtr==4)*vs*(1-same))
by lbdnumd: egen numer5=sum(vs*(1-same))
forvalues x=1/4 {
   gen qtrFrac`x'=numer`x'/numer5
}
gen avgsizeOfCust=log(numer5)
gen avgsizeOfShip=log(numer5/denom)
gen avgMarkupMean=numer/denom
drop numer denom
keep if ltfpqd~=. 
gen matchprice0=1
gen matchprice1=(abs(priceI-priceI_CFS)<.8)
gen matchprice2=(abs(priceI-priceI_CFS)<.4)

forvalues ii=1/2 { 
  forvalues jj=1/3 {
  gen todrop0_`ii'_`jj'=0
  gen todrop1_`ii'_`jj'=0 
  gen todrop2_`ii'_`jj'=0
 }
}

gen fracTest_1=0.05
gen fracTest_2=0.15
gen fracTest_3=0.25
gen countTest_1=2
gen countTest_2=.

forvalues ii=1/2 {
 forvalues jj=1/3 {
  forvalues x=0/2 {
    qui sum ltfpqd if   fiD==1 & matchprice`x'==1 & fracsame<=fracTest_`jj' & indd==3273 , detail 
    qui replace todrop`x'_`ii'_`jj'=1 if ( abs(ltfpqd-r(mean))>`outlie' )  & fiD==1 & matchprice`x'==1 & fracsame<=fracTest_`jj' 
    qui sum tfpq_Up_W if    fiD==1 & matchprice`x'==1 & fracsame<=fracTest_`jj' & indd==3273 , detail 
    qui replace todrop`x'_`ii'_`jj'=1 if ( abs(tfpq_Up_W-r(mean))>`outlie') & fiD==1 & matchprice`x'==1 & fracsame<=fracTest_`jj'
    qui replace todrop`x'_`ii'_`jj'=1 if count>countTest_`ii'
    qui replace todrop`x'_`ii'_`jj'=1 if fracsame>=fracTest_`jj'
    bys lbdnumd year: egen t=max(todrop`x'_`ii'_`jj')
    replace todrop`x'_`ii'_`jj'=t
    drop t
  }
 }
} 

merge n:1 dest_zip using priceO_1
drop if _merge==2
drop _merge
replace group=group+100
replace groupd=10 /* Make the downstream sample group no. equal to 10 */
replace price50=log(price50)
replace price100=log(price100)
replace price150=log(price150)
replace price100=price150 if price100==.
replace price50=price100 if price50==.
save sampleNoBox, replace
append using emptyDset
save esumNoBox, replace

forvalues ii=1/2 {
 forvalues jj=1/3 {
  forvalues x=0/2 {
  gen ltfpqd_`x'_`ii'_`jj'=.
  gen tfpq_Up_W_`x'_`ii'_`jj'=.
  gen priceI_CFS_`x'_`ii'_`jj'=.
  gen ltfpqd_`x'_`ii'_`jj'_W=.
  gen tfpq_Up_W_`x'_`ii'_`jj'_W=.
  gen priceI_CFS_`x'_`ii'_`jj'_W=.
  forvalues xxx=50(50)150 {
     gen price`xxx'_`x'_`ii'_`jj'_W=.
     gen price`xxx'_`x'_`ii'_`jj'=.
  }
  forvalues yr=1992(5)1992 {
   forvalues gro==10/10 { 
    qui sum ltfpqd if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace ltfpqd_`x'_`ii'_`jj'=ltfpqd-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum price50 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace price50_`x'_`ii'_`jj'=price50-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price100 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace price100_`x'_`ii'_`jj'=price100-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price150 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace price150_`x'_`ii'_`jj'=price150-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum tfpq_Up_W if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace tfpq_Up_W_`x'_`ii'_`jj'=tfpq_Up_W-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum priceI_CFS if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui replace priceI_CFS_`x'_`ii'_`jj'=priceI_CFS-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum ltfpqd if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace ltfpqd_`x'_`ii'_`jj'_W=ltfpqd-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum tfpq_Up_W if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace tfpq_Up_W_`x'_`ii'_`jj'_W=tfpq_Up_W-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price50 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace price50_`x'_`ii'_`jj'_W=price50-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price100 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace price100_`x'_`ii'_`jj'_W=price100-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price150 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace price150_`x'_`ii'_`jj'_W=price150-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum priceI_CFS if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd] 
    qui replace priceI_CFS_`x'_`ii'_`jj'_W=priceI_CFS-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj' & matchprice`x'==1
    qui gen ltfpq3_`x'_`ii'_`jj'_W= ltfpqd_`x'_`ii'_`jj'_W
    qui gen ltfpq3_`x'_`ii'_`jj'= ltfpqd_`x'_`ii'_`jj'
   } 
  }
}
}
}
if `runRegs'==1 {
 do runRegs_rev
 gen sample="Concrete"
 keep price_* tfp_* phi_* sample* divO* disp* iii jjj ddd xxx kkk mn_d* sd_d* ppp
 save concreteRegResults, replace
}
use sampleBox , replace
destring  mcf mf mqdcf ppc, replace force
append using sampleNoBox
save samplePooled, replace

gen sample="Pooled"

forvalues ii=1/2 {
 forvalues jj=1/3 {
 forvalues x=0/2 {
  gen ltfpqd_`x'_`ii'_`jj'=.
  gen tfpq_Up_W_`x'_`ii'_`jj'=.
  gen priceI_CFS_`x'_`ii'_`jj'=.
  gen ltfpqd_`x'_`ii'_`jj'_W=.
  gen tfpq_Up_W_`x'_`ii'_`jj'_W=.
  gen priceI_CFS_`x'_`ii'_`jj'_W=.
  forvalues xxx=50(50)150 {
     gen price`xxx'_`x'_`ii'_`jj'_W=.
     gen price`xxx'_`x'_`ii'_`jj'=.
  }
   /* For different sample selection criteria, different subsamples will be included.  Depending on which subsamples are included, de-mean 
    variables by industry-year */
  forvalues yr=1992(5)1997 {
   forvalues gro==8/10 { 
    qui sum ltfpqd if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    replace ltfpqd_`x'_`ii'_`jj'=ltfpqd-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum tfpq_Up_W if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    replace tfpq_Up_W_`x'_`ii'_`jj'=tfpq_Up_W-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui sum priceI_CFS if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1
      replace priceI_CFS_`x'_`ii'_`jj'=priceI_CFS-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum ltfpqd if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    replace ltfpqd_`x'_`ii'_`jj'_W=ltfpqd-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum tfpq_Up_W if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    replace tfpq_Up_W_`x'_`ii'_`jj'_W=tfpq_Up_W-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum priceI_CFS if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd] 
    replace priceI_CFS_`x'_`ii'_`jj'_W=priceI_CFS-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price50 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace price50_`x'_`ii'_`jj'=price50-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price100 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1 
    qui replace price100_`x'_`ii'_`jj'=price100-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price50 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace price50_`x'_`ii'_`jj'_W=price50-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
    qui sum price100 if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr'  & fracsame<=fracTest_`jj'  & matchprice`x'==1 [aw=tvsd]
    qui replace price100_`x'_`ii'_`jj'_W=price100-r(mean) if todrop`x'_`ii'_`jj'==0 & fiD==1 & groupd==`gro' & year==`yr' & fracsame<=fracTest_`jj'  & matchprice`x'==1
   } 
  }
   gen ltfpq3_`x'_`ii'_`jj'_W=ltfpqd_`x'_`ii'_`jj'_W
   gen ltfpq3_`x'_`ii'_`jj'=ltfpqd_`x'_`ii'_`jj'
} 
}
}
if `runRegs'==1 {
 do runRegs_rev
 format price_* tfp_* phi_* divO* disp* mn_d* sd_d* %12.4f 
 keep price_* tfp_* phi_* sample* divO* disp* iii jjj ddd xxx kkk mn_d* sd_d* ppp
 append using concreteRegResults
 append using boxRegResults
 keep  if xxx==0 & jjj==2
 drop xxx jjj *UW_*  
 sort sample iii kkk ddd ppp
 foreach var of varlist phi* *Phi* {
   replace `var'=. if sample~="Boxes"
 }
outsheet using supplierRegs.csv, delim(,) replace
}

/* dispersions of suppliers' marginal costs */

use samplePooled, replace
gen coefC=.
gen coefB=.
reg tfpq_Up_W i.year  if fiD==1 & todrop0_2_2==0 & groupd==10 [aw=tvsd]
replace coefC=e(rmse) in 1/1
reg tfpq_Up_W i.year i.divd if fiD==1 & todrop0_2_2==0 & groupd==10 [aw=tvsd]
replace coefC=e(rmse) in 2/2
reg tfpq_Up_W i.year  if fiD==1 & todrop0_2_2==0 & groupd==10 
replace coefC=e(rmse) in 3/3
reg tfpq_Up_W i.year i.divd if fiD==1 & todrop0_2_2==0 & groupd==10 
replace coefC=e(rmse) in 4/4
reg tfpq_Up_W i.year  if fiD==1 & todrop0_2_2==0 & groupd~=10 [aw=tvsd]
replace coefB=e(rmse) in 1/1
reg tfpq_Up_W i.year i.divd if fiD==1 & todrop0_2_2==0 & groupd~=10 [aw=tvsd]
replace coefB=e(rmse) in 2/2
 reg tfpq_Up_W i.year  if fiD==1 & todrop0_2_2==0 & groupd~=10 
replace coefB=e(rmse) in 3/3
reg tfpq_Up_W i.year i.divd if fiD==1 & todrop0_2_2==0 & groupd~=10 
replace coefB=e(rmse) in 4/4
keep coefC coefB
keep in 1/4
outsheet using supplierDevs.csv, replace delim(,)

/* Spatial Correlation */

if `spatial'==1 {
 forvalues xxx=1/16   {
 di `xxx' 
 qui { 
   use if ltfpq3~=. & group<=16 using esumSamp1, replace
   if `xxx'~=10 & `xxx'~=11 {
     keep if  group==`xxx'
   }
   if `xxx'==10 | `xxx'==11 {
     keep if group==3
   }
   keep lpriceP cou fipsst lbdnum year group tvs
  foreach var of varlist lpriceP cou fipsst lbdnum tvs { 
    ren `var' `var'Other
   }
   joinby group year using esumSamp1
   if `xxx'==10 {
     keep if div<=7
   }
   if `xxx'==11 {
     keep if div>=8
   }
   keep if ltfpq~=.
   keep *Other lpriceP cou fipsst lbdnum year group tvs
   ren couOther  county
   ren fipsstOther  state
   replace county=23 if county==25 & state==12  
   replace county=195 if county==193 & state==29
   replace county=215 if county==510 & state==13
   replace county=775 if county==780 & state==51
   replace county=170 if county==120 & state==2
   replace cou=23 if cou==25 & fipsst==12  
   replace cou=195 if cou==193 & fipsst==29
   replace cou=215 if cou==510 & fipsst==13
   replace cou=775 if cou==780 & fipsst==51
   replace cou=170 if cou==120 & fipsst==2
   merge n:1 county state using countylocs
   drop if _merge==2
   drop _merge
   ren county couOther 
   ren state fipsstOther
   ren longitude longitudeOther
   ren latitude latitudeOther
   ren cou county
   ren fipsst state
   merge n:1 county state using countylocs
   drop if _merge==2
   ren county cou
   ren state fipsst
   gen mileage=sqrt( 69.31^2 * (latitude-latitudeOther)^2 + 53.0^2 * (longitude-longitudeOther)^2)  
   drop if lbdnum==lbdnumOther
   sort lbdnum year mileage
   gen close=(mileage<300)
   by lbdnum year: egen s=sum(close)
   gen inter_1_=close*lpricePOther
   gen inter_2_=close*lpricePOther*tvsOther
   gen inter_3_=close*tvsOther
   by lbdnum year: egen mnclose_=mean(inter_1_) 
   by lbdnum year: egen ss2_=sum(inter_2_)
   by lbdnum year: egen ss3_=sum(inter_3_)
   gen mncloseW_=ss2_/ss3_
   ren lpricePOther closest
   by lbdnum year: keep if _n==1
   if `xxx'==10 | `xxx'==11 {
      replace group=`xxx'
   }
   keep lbdnum lpriceP year group closest tvs mnclose* s
   save spatial_`xxx', replace
  }
 }

 use spatial_1, replace 
 forvalues xxx=2/16 {
   append using spatial_`xxx'
 }
 save spatial, replace
}
 use spatial, replace
 replace mncloseW_=0 if mncloseW_==.  /* So that the sample count doesn't bounce around, replace with 0- for a small number of observations that do not
                                        have same industryXyear neighbor, within 300 miles of the plant.  I've checked that this  replacement 
                                       doesn't affect the results */
 forvalues x=1/16 {
    gen coef`x'=.
    reg lpriceP mncloseW_ if group==`x' [aw=tvs]
    replace coef`x'=_b[mncloseW_] in 1/1
    replace coef`x'=_se[mncloseW_] in 2/2
    replace coef`x'=e(r2_a) in 3/3
    replace coef`x'=e(rmse) in 9/9
    qui sum mncloseW_ if  group==`x' [aw=tvs]
    replace coef`x'=r(sd) in 7/7
    qui sum lpriceP if  group==`x' [aw=tvs]
    replace coef`x'=r(sd) in 11/11
    reg lpriceP mncloseW_ if group==`x'
    replace coef`x'=_b[mncloseW_] in 4/4
    replace coef`x'=_se[mncloseW_] in 5/5
    replace coef`x'=e(r2_a) in 6/6
    replace coef`x'=e(rmse) in 10/10
    qui sum mncloseW_ if  group==`x' 
    replace coef`x'=r(sd) in 8/8
    qui sum lpriceP if  group==`x' 
    replace coef`x'=r(sd) in 12/12

 }
 gen coef17=.
 gen coef18=.
 reg lpriceP mncloseW_ if group<=9 | group==12 [aw=tvs]
 replace coef17=_b[mncloseW_] in 1/1
 replace coef17=_se[mncloseW_] in 2/2
 replace coef17=e(r2_a) in 3/3
 replace coef17=e(rmse) in 9/9
 qui sum mncloseW_ if group<=9 | group==12 [aw=tvs]
 replace coef17=r(sd) in 7/7
 qui sum lpriceP if group<=9 | group==12 [aw=tvs]
 replace coef17=r(sd) in 11/11
 reg lpriceP mncloseW_ if  group>=13 & group<=16  [aw=tvs]
 replace coef18=_b[mncloseW_] in 1/1
 replace coef18=_se[mncloseW_] in 2/2
 replace coef18=e(r2_a) in 3/3
 replace coef18=e(rmse) in 9/9
 qui sum mncloseW_ if  group>=13 & group<=16 
 replace coef18=r(sd) in 7/7
 qui sum lpriceP if  group>=13 & group<=16 
 replace coef18=r(sd) in 11/11

 reg lpriceP mncloseW_ if group<=9 | group==12 
 replace coef17=_b[mncloseW_] in 4/4
 replace coef17=_se[mncloseW_] in 5/5
 replace coef17=e(r2_a) in 6/6
 replace coef17=e(rmse) in 10/10
 qui sum mncloseW_ if  group<=9 |  group==12 [aw=tvs]
 replace coef17=r(sd) in 8/8
 qui sum lpriceP if  group<=9 |  group==12 [aw=tvs]
 replace coef17=r(sd) in 12/12
 reg lpriceP mncloseW_ if  group>=13 & group<=16  
 replace coef18=_b[mncloseW_] in 4/4
 replace coef18=_se[mncloseW_] in 5/5
 replace coef18=e(r2_a) in 6/6
 replace coef18=e(rmse) in 10/10
 qui sum mncloseW_ if  group>=13 & group<=16 
 replace coef18=r(sd) in 8/8
 qui sum lpriceP if  group>=13 & group<=16 
 replace coef18=r(sd) in 12/12
 keep coef*
 keep in 1/12
 outsheet using spatialResults.csv, replace delim(,)

/* Caves et al. (1982) Productivity */
if `caves'==1 {
use if  group<=12 using esumSamp1, replace
gen Vm1=vm*share if group==3 & m=="144201"
gen Vm2=vm*share if group==3 & m=="324101"
sort lbdnum year
by lbdnum year: egen vm1=min(Vm1)
by lbdnum year: egen vm2=min(Vm2)
drop Vm1 Vm2
keep if ltfpq3~=.
bys group year: egen mnshare=mean(share)
gen coef1=vm/(vm+mae*strkl+mae*eqrkl+ee+sw) if group~=3
gen coef1a=vm1/(vm+mae*strkl+mae*eqrkl+ee+sw) if group==3
gen coef1b=vm2/(vm+mae*strkl+mae*eqrkl+ee+sw) if group==3
gen coef2=ee/(vm+mae*strkl+mae*eqrkl+ee+sw)
gen coef3=sw/(vm+mae*strkl+mae*eqrkl+ee+sw)
gen coef4a=(strkl*bae)/(vm+bae*strkl+mae*eqrkl+ee+sw)
gen coef4b=(eqrkl*mae)/(vm+bae*strkl+mae*eqrkl+ee+sw)
gen lvm=log(vm)
gen lvm1=log(vm1)
gen lvm2=log(vm2)
gen lee=log(ee)
sort group year
foreach var of varlist coef1-coef4b {
  by group year: egen `var'_M=mean(`var')
}

gen ltfpqI=lpq-1/2*(lbae*(coef4a+coef4a_M)+lmae*(coef4b+coef4b_M)+(coef3+coef3_M)*lte+lvm*(coef1+coef1_M)+lee*(coef2_M+coef2)) if group~=3
replace ltfpqI=lpq-1/2*(lbae*(coef4a+coef4a_M)+lmae*(coef4b+coef4b_M)+(coef3+coef3_M)*lte+lvm1*(coef1a+coef1a_M)+lvm2*(coef1b+coef1b_M)+lee*(coef2_M+coef2)) if group==3
gen ltfprI=ltfpqI+lpriceout
gen ltfpq3I=log(exp(ltfpqI)*(pimat/exp(lpriceP))^(-coef1*(mnshare2+share2)/2)) if  group~=3
replace ltfpq3I=log(exp(ltfpqI)*(pimat/exp(lpriceP))^(-coef1a*(mnshare2*mnshare+share2*share)/2-coef1b*(mnshare2*(1-mnshare)+share2*(1-share))/2)) if group==3
foreach var of varlist ltfpqI-ltfpq3I {
 by group year: egen mn=mean(`var')
 replace `var'=`var'-mn
 cap drop mn
}
keep ltfp*I group year lbdnum tvs firmid 
save esumCaves, replace

forvalues xxx=1/1000 {
use esumCaves, replace
bsample, strata(group year)
foreach var of varlist  ltfp*    {
 by group year: egen mn=mean(`var')
 qui replace `var'=`var'-mn
 cap drop mn
}

cap gen ones=1
foreach var of varlist ltfp* {
qui {
  myQuant `var' tvs
  local  ninetytenW`var'_Disc_`xxx'=real(r(r4))-real(r(r1))
  local  iqrW`var'_Disc_`xxx'=real(r(r3))-real(r(r2)) 
  myQuant `var' ones
  local ninetyten`var'_Disc_`xxx'=real(r(r4))-real(r(r1)) 
  local iqr`var'_Disc_`xxx'=real(r(r3))-real(r(r2))  
  sum `var' [aw=tvs]
  local  sdW`var'_`xxx'=r(sd)
  sum `var'
  local sd`var'_`xxx'=r(sd)
} 
}
}

foreach var of varlist ltfp* {
gen coef1`var'=.
gen coef2`var'=.
gen coef3`var'=.
gen coef4`var'=.
gen coef5`var'=.
gen coef6`var'=.

/* Compute the bootstrapped 95% confidence interval for the difference in the dispersion of TFPQ vs (TFPR or Phi) */

forvalues  xxx=1/1000 {
    replace coef1`var'=`ninetytenW`var'_Disc_`xxx''        in `xxx'/`xxx'
    replace coef2`var'=`ninetyten`var'_Disc_`xxx''        in `xxx'/`xxx'
    replace coef3`var'=`iqrW`var'_Disc_`xxx''       in `xxx'/`xxx'
    replace coef4`var'=`iqr`var'_Disc_`xxx''        in `xxx'/`xxx'
    replace coef5`var'=`sdW`var'_`xxx''       in `xxx'/`xxx'
    replace coef6`var'=`sd`var'_`xxx''        in `xxx'/`xxx'
  }
 }

gen difftfpq3_9010= exp(coef2ltfpqI/coef2ltfpq3I-1)
gen difftfpr_9010= exp(coef2ltfpqI/coef2ltfprI-1)
gen difftfpq3_9010W= exp(coef1ltfpqI/coef1ltfpq3I-1)
gen difftfpr_9010W= exp(coef1ltfpqI/coef1ltfprI-1)
gen difftfpq3_7525= exp(coef4ltfpqI/coef4ltfpq3I-1)
gen difftfpr_7525= exp(coef4ltfpqI/coef4ltfprI-1)
gen difftfpq3_7525W=exp(coef3ltfpqI/coef3ltfpq3I-1)
gen difftfpr_7525W= exp(coef3ltfpqI/coef3ltfprI-1)
gen difftfpq3_sd= exp(coef6ltfpqI/coef6ltfpq3I-1)
gen difftfpr_sd= exp(coef6ltfpqI/coef6ltfprI-1)
gen difftfpq3_sdW=exp(coef5ltfpqI/coef5ltfpq3I-1)
gen difftfpr_sdW= exp(coef5ltfpqI/coef5ltfprI-1)
gen resltfpqI=.
gen resltfprI=.
gen resltfpq3I=.
gen resltfpqIW=.
gen resltfprIW=.
gen resltfpq3IW=.
gen x=_n
foreach var of varlist ltfp* {
qui {
  myQuant `var' tvs
  replace  res`var'W=real(r(r4))-real(r(r1)) in 1/1
  replace  res`var'W=real(r(r3))-real(r(r2)) in 2/2
  myQuant `var' ones
  replace  res`var'=real(r(r4))-real(r(r1)) in 1/1
  replace  res`var'=real(r(r3))-real(r(r2)) in 2/2
  sum `var' [aw=tvs]
  replace res`var'W=r(sd) in 3/3
  sum `var'
  replace res`var'=r(sd) in 3/3
}
}
foreach var of varlist difft* {
 sort `var'
 local hi`var'=1/2*(`var'[976]+`var'[975])
 local lo`var'=1/2*(`var'[25]+`var'[26])
}
sort x
replace resltfprI=`hidifftfpr_9010'  in 4/4
replace resltfprI=`hidifftfpr_7525'  in 5/5
replace resltfprI=`hidifftfpr_sd'  in 6/6
replace resltfprI=`lodifftfpr_9010'  in 7/7
replace resltfprI=`lodifftfpr_7525'  in 8/8
replace resltfprI=`lodifftfpr_sd'  in 9/9
replace resltfprIW=`hidifftfpr_9010W'  in 4/4
replace resltfprIW=`hidifftfpr_7525W'  in 5/5
replace resltfprIW=`hidifftfpr_sdW'  in 6/6
replace resltfprIW=`lodifftfpr_9010W'  in 7/7
replace resltfprIW=`lodifftfpr_7525W'  in 8/8
replace resltfprIW=`lodifftfpr_sdW'  in 9/9
replace resltfpq3I=`hidifftfpq3_9010'  in 4/4
replace resltfpq3I=`hidifftfpq3_7525'  in 5/5
replace resltfpq3I=`hidifftfpq3_sd'  in 6/6
replace resltfpq3I=`lodifftfpq3_9010'  in 7/7
replace resltfpq3I=`lodifftfpq3_7525'  in 8/8
replace resltfpq3I=`lodifftfpq3_sd'  in 9/9
replace resltfpq3IW=`hidifftfpq3_9010W'  in 4/4
replace resltfpq3IW=`hidifftfpq3_7525W'  in 5/5
replace resltfpq3IW=`hidifftfpq3_sdW'  in 6/6
replace resltfpq3IW=`lodifftfpq3_9010W'  in 7/7
replace resltfpq3IW=`lodifftfpq3_7525W'  in 8/8
replace resltfpq3IW=`lodifftfpq3_sdW'  in 9/9
keep res* 
keep in 1/9
outsheet using cavesResults.csv, replace delim(,)

}

/* Mean and standard deviation of materials prices for ready-mix-concrete plants */

use if group==3 using esumSamp1, replace
keep if ltfpq~=.
gen rr=1 if div<=7
replace rr=2 if div>=8
gen coef1=.
gen coef2=.
sum lpriceP if rr==1
  replace coef1=r(mean) in 1/1
replace coef1=r(sd) in 2/2
sum lpriceP if rr==2
replace coef2=r(mean) in 1/1
replace coef2=r(sd) in 2/2
sum lpriceP if rr==1 [aw=tvs]
replace coef1=r(mean) in 3/3
replace coef1=r(sd) in 4/4
sum lpriceP if rr==2 [aw=tvs]
replace coef2=r(mean) in 3/3
replace coef2=r(sd) in 4/4
keep coef1 coef2
keep coef1 coef2
keep in 1/4
outsheet using cement4Nums.csv, replace delim(,)

/* Non-production worker share calculations.  See footnote 18 of the paper. */
use if group<=12 & ltfpq~=. using esumSamp1, replace
gen npw=max(0, (te-pw)/te)
gen lnpw=log(npw)
sort group year
by group year: egen m1=min(lnpw)  /* Replace a small number of observations with the minimum of that group-year */
replace lnpw=m1 if lnpw==.  
by group year: egen m2=mean(lnpw)
replace lnpw=lnpw-m2
by group year: egen m3=mean(npw)
replace npw=npw-m3
drop m1 m2 m3
gen coef1=.
gen coef2=.
gen coef3=.
gen coef4=.
local count=0
foreach var of varlist ltfpr ltfpq ltfpq3 lpriceP lpriceout{
  local count=`count'+1
  cor `var' npw  
  replace coef1=r(rho) in `count'/`count'
  cor `var' npw  [aw=tvs]
  replace coef2=r(rho) in `count'/`count'
  cor `var' lnpw 
  replace coef3=r(rho) in `count'/`count'
  cor `var' lnpw [aw=tvs]
  replace coef4=r(rho) in `count'/`count'
}
keep coef1-coef4
keep in 1/5
outsheet using npwResults.csv, replace delim(,)

/* These calculations, below, correspond to appendix A.11 of the paper */

use esumBox, replace
drop *f ppc
append using esumNoBox
gen size=log(weight)

gen coef1=.
gen coef2=.
gen coef3=.
gen coef4=.
gen coef5=.
gen coef6=.

gen qtr2=(qtr==2)
gen qtr3=(qtr==3)
gen qtr4=(qtr==4)
gen new=(groupd~=10)
forvalues x=1/3 {

 if `x'==1 {
    local gr1=10 
    local gr2=10
 } 
 if `x'==2 {
    local gr1=8 
    local gr2=9
 } 
 if `x'==3 {
    local gr1=8 
    local gr2=10
 } 
  local y=`x'+3
  reg relpriceMean qtr2-qtr4 size new if  todrop0_2_2==0 & groupd>=`gr1' & groupd<=`gr2'  [aw=vs], cluster(lbdnumd)
  replace coef`x'=_b[qtr2] in 1/1
  replace coef`x'=_se[qtr2] in 2/2
  replace coef`x'=_b[qtr3] in 3/3
  replace coef`x'=_se[qtr3] in 4/4
  replace coef`x'=_b[qtr4] in 5/5
  replace coef`x'=_se[qtr4] in 6/6
  replace coef`x'=_b[size] in 7/7
  replace coef`x'=_se[size] in 8/8
  replace coef`x'=_b[_cons] in 9/9
  replace coef`x'=_se[_cons] in 10/10
  replace coef`x'=e(r2) in 11/11
  replace coef`x'=e(N) in 12/12

  reg relpriceMean qtr2-qtr4  new if  todrop0_2_2==0 & groupd>=`gr1' & groupd<=`gr2'  [aw=vs], cluster(lbdnumd)
  replace coef`x'=_b[qtr2] in 13/13
  replace coef`x'=_se[qtr2] in 14/14
  replace coef`x'=_b[qtr3] in 15/15
  replace coef`x'=_se[qtr3] in 16/16
  replace coef`x'=_b[qtr4] in 17/17
  replace coef`x'=_se[qtr4] in 18/18
  replace coef`x'=_b[_cons] in 19/19
  replace coef`x'=_se[_cons] in 20/20
  replace coef`x'=e(r2) in 21/21
  replace coef`x'=e(N) in 22/22

  reg avgMarkupMean qtrFrac2-qtrFrac4 avgsizeOfShip new if todrop0_2_2==0 & groupd>=`gr1' & groupd<=`gr2' & fiD==1  [aw=tvsd], robust
  replace coef`y'=_b[qtrFrac2] in 1/1
  replace coef`y'=_se[qtrFrac2] in 2/2
  replace coef`y'=_b[qtrFrac3] in 3/3
  replace coef`y'=_se[qtrFrac3] in 4/4
  replace coef`y'=_b[qtrFrac4] in 5/5
  replace coef`y'=_se[qtrFrac4] in 6/6
  replace coef`y'=_b[avgsizeOfShip] in 7/7
  replace coef`y'=_se[avgsizeOfShip] in 8/8
  replace coef`y'=_b[_cons] in 9/9
  replace coef`y'=_se[_cons] in 10/10
  replace coef`y'=e(r2) in 11/11
  replace coef`y'=e(N) in 12/12

  reg avgMarkupMean qtrFrac2-qtrFrac4  new if todrop0_2_2==0 & groupd>=`gr1' & groupd<=`gr2' & fiD==1  [aw=tvsd], robust
  replace coef`y'=_b[qtrFrac2] in 13/13
  replace coef`y'=_se[qtrFrac2] in 14/14
  replace coef`y'=_b[qtrFrac3] in 15/15
  replace coef`y'=_se[qtrFrac3] in 16/16
  replace coef`y'=_b[qtrFrac4] in 17/17
  replace coef`y'=_se[qtrFrac4] in 18/18
  replace coef`y'=_b[_cons] in 19/19
  replace coef`y'=_se[_cons] in 20/20
  replace coef`y'=e(r2) in 21/21
  replace coef`y'=e(N) in 22/22

}
keep coef1-coef6
keep in 1/22

outsheet using acrossBuyer.csv, replace delim(,)