  /* This sas file retrieves the data necc. for the paper.
Besides Census-collected data, the project uses a dataset
called "external", which contains information on price-indicies
and production cost shares of different 4-digit SIC industries 
(from 1972-2000).  The output of this .sas file 
are .csv files which will be used by masteranalysis.do (which will,
in turn, produce the tables and figures of the paper).  The code takes
about 10 minutes to run.

Outputs produced by this sas file: 

limestone.csv : aggregate employment in the crushed limestone mining industry
persist.csv   : shipment information, from the 1993 & 1997 CFS for cement/
                paperboard manufacturers (that are present in both years)
firmlocs.csv  : zip codes in which firms own plants 
cementCFS.csv : used in section 4, information on buyer-supplier relationships 
                btw. cement manufacturers and their downstream buyers (including 
                info on productivity & materials usage (from the CM)
boxesCFS.csv  : same as cementCFS.csv, but for paperboard manufacturers 
cmat.csv      : information, from the LBD and CM, on materials usage & production  
                for the main sample of firms (for Section 3 of the paper)
ppnlist.csv   : basic information, from the LBD, on plants that are present
                in the industries of the plants within cmat
twoinds.csv   : list of all plants in paperboard (2631) and cement (3241) for 1992 
                and 1997
cfsFull.csv   : shipments from the 1993/1997 Commodity Flow Surveys

*/

libname outside '/rdcprojects/ch/ch00573/data/outside';
libname lbd '/economic/lbd/legacy/C200907';
libname cfs '/economic/cfs/microdata';
libname cmf '/economic/cmf.old/microdata';

/* The following macro downloads data from the 1972-1997 versions of the Census of Manufacturers, for the 10
   different industries that are considered in Section 3 of the paper. 
*/

%macro oneyear(yr);

%let mat=mat;
%let c=c;
%let yrc=&yr&c;
%let yrmat=&yr&mat;
%let prod=prod;
%let yrprod=&yr&prod;

data cm1 (keep=cfn ppn cp m  mc mcf mf mqdc mqdcf mqpc tvmc);
  set cmf.cmf&yrmat;
run;

data cm2 (keep=cou fipsst ind cfn ppn ph bae mae tae ppc  pe ee cm sw ww lbdnum year div fcm2 ar reg tvs  cp cr cw mib mie npw pw);
  set cmf.cmf&yr;
  if ar~=1;  /* Drop Administrative Record establishments */
run;
   
%if %eval(&yr)>1975 %then %do;  /* The LBD does not exist prior to 1977, so don't try to download it for 1972 */
data lbd (keep=emp county firmid mu firstyear lastyear zip5 state cfn);
   set lbd.lbd&yrc;
   zip5=substr(zip,1,5)/1;
run;

proc sql noprint;       /* Combine materials input data with the LBD */
  create table cm2a as 
  select a.*, b.*
  from cm2 as a left join lbd as b
  on a.cfn=b.cfn;

data cm2;
   set cm2a;
   rename zip5=zip;
run;

%end;

data  cm3;
  set cmf.cmf&yrprod;
  year=%eval(&yr);
  if curpc="2026112" OR curpc="2026115"  then group=1;
  if curpc="2026212" OR curpc="2026223" OR curpc="2026225"  then group=12;
  else if curpc="2041105" OR curpc="2041107" OR curpc="2041111" OR curpc="2041113" OR curpc="2041117" then group=2;
  else if curpc="2041121" OR curpc="2041121" OR curpc="2041123" OR curpc="2041126" OR curpc="2041128" OR curpc="2041129" then group=2;
  else if curpc="3273000" OR curpc="3273011" then group=3;
  else if curpc="2281110" OR curpc="2281187" then group=4;
  else if curpc="2653012" OR curpc="2653013" OR curpc="2653015" OR curpc="2653016" OR curpc="2653018" OR curpc="2653021" then group=5;
  else if curpc="2653030" OR curpc="2653022" OR  curpc="2653029"  then group=5; 
  else if curpc="2911131" OR curpc="2911412" OR curpc="2911414" then group=6;
  else if curpc="2095115" OR curpc="2095111" then group=7;
  else if curpc="2061011" then group=8;
  else if substr(curpc,1,4)="2895" then group=11;  /* This is the industry code for carbon black, which was originally in the sample, but for which there were too few establishments to pass disclosure */
  else if substr(curpc,1,6)="208401" AND curpc~="2084019"   then group=13;
  else if substr(curpc,1,5)="24217" AND curpc~="2421700" then group=14;
  else if substr(curpc,1,6)="203521"  then group=15;
  else if curpc="2011717" OR curpc="2013717" OR curpc="2011721" OR curpc="2013721" OR curpc="2011735" OR curpc="2013735" then group=16;
   /* Begninning in 1992, the way in which cardboard box output is coded changes (prior to 1992, the output is stated in terms 
      of mass.  After 1992, output is stated in terms of square feet.  Since different types of cardboard boxes have different 
      densities, we will need to split apart the different types of cardboard boxes into groups of similar densities.  Otherwise,
      the producers of particularly dense cardboard boxes will seem to be less productive, beginning in 1992.  */
  if group=5 AND year>1990 AND (curpc="2653012" OR curpc="2653013" OR curpc="2653014" OR curpc="2653015") then group=9;
  if group=5 AND year>1990 AND (curpc="2653016" OR curpc="2653018" OR curpc="2653021" OR curpc="2653022" OR  curpc="2653029" OR curpc="2653030") then group=10;
  if group ~=.;
  if group=3 AND year>=1987 then pqs=pqs/1000;  /* Concrete output is off by a factor of 1000, beginning in 1987 */
  if pqs>0;
  if pqsf ~= "I" AND pqsf ~="B";
  price=pv/pqs;
run;

proc sort data=cm3;
   by cfn group;
run;

proc summary data=cm3;
  var pv;
  output out=sumval (drop=_type_ _freq_) sum=sumval;
  by cfn group;
run;

proc summary data=cm3;
  var pqs;
 output out=sumquant (drop=_type_ _freq_) sum=sumquant;
  by cfn group;
run;

proc sql noprint; 
  create table c3 as
  select a.*, b.sumval
  from cm3 as a, sumval as b
  where a.cfn=b.cfn AND a.group=b.group;
  create table cm3 as
  select a.*, b.sumquant
  from c3 as a, sumquant as b
  where a.cfn=b.cfn AND a.group=b.group;

proc sort data=cm3;
  by cfn  DESCENDING sumval;
run;

data cm3;
  set cm3;
  by cfn;  
  if first.cfn;
  fracOut=sumval/tvs;
  priceOut=sumval/sumquant;
  keep sumval sumquant fracOut priceOut group cfn;
  if fracOut>=.5;  /* As in Foster, Haltiwanger, and Syverson, only consider plants which have at least half of their revenues from  
                   the product in question */
run;

proc sql noprint;
  create table cmA as 
  select a.*, b.*
  from cm1 as a right join cm2 as b
  on a.cfn=b.cfn;
  create table cm as 
  select a.*, b.*
  from cmA as a, cm3 as b
  where a.cfn=b.cfn;

proc append base=cmAgg data=cm force;

%mend;

%oneyear(1987);
%oneyear(1972);
%oneyear(1977);
%oneyear(1982);
%oneyear(1992);
%oneyear(1997);

data d1;
  set cmAgg;
  if year=1977;
run;

proc sql noprint;
   create table produc as 
   select a.*, b.iae, b.iake, b.iaks, b.ial, b.iam, b.eqrkl, b.strkl, piinve, piinvs, pimat, piship
   from cmAgg as a, outside.external as b
   where a.ind=b.myind and a.year=b.year;

data product;
   set produc;
   if year=1997 then bae=tae*(1-iake/(iake+iaks));  /* In 1997, the bae and mae variables are missing.  Impute these variables, for this year, using  
                                                        information on the total assess of each plant */
   if year=1997 then mae=tae*(iake/(iake+iaks));
   vm=cr+cp+cw+(mib-mie);
   lpq=log(sumquant/fracOut);
   lbae=log(bae/strkl);
   lmae=log(mae/eqrkl);
   lmatM=log((vm)/pimat);
   lmatE=log((ee)/pimat);
   lte=log(ph*sw/ww);
   ltfpq=lpq-lbae*iaks-lmae*iake-ial*lte-lmatM*iam-lmatE*iae;
run;

data ppnlist (keep=ppn);  /* Get all of the plants that are in the main (cmat) sample */
  set product;
run;
proc sort data=ppnlist nodupkey;
  by ppn;
run;

/* Also get other plants from the industries of the main-sample plants.
    This will be important, since we want to know   whether the plants in our 
 sample are representative of their respective industries   (turns out not to be the case)  */

%macro oneyear2(yr);
  data c1 (keep=ppn);
    set cmf.cmf&yr ;
    if ind=2026 | ind=2041 | ind=2281 | ind=3273 | ind=2061 | ind=2095 | ind=2653 | ind=2911 | ind=2895  | ind=2013 | ind=2035 | ind=2084 | ind=2421;
  proc append base=ppnlist2 data=c1;

  proc sort data=ppnlist2 nodupkey;
    by ppn;
  run;
%mend;

%oneyear2(1963);
%oneyear2(1967);
%oneyear2(1972);
%oneyear2(1977);
%oneyear2(1982);
%oneyear2(1987);
%oneyear2(1992);
%oneyear2(1997);

data ppnlist;
  set ppnlist;
  sampYes=1;
run;
data ppnlist2;  
  set ppnlist2;
  sampYes=0;  /* These will be the plants that are not in the main (cmat) sample */
run;

proc append base=ppnlist data=ppnlist2;

proc sort data=ppnlist;
  by ppn DESCENDING sampyes;
run;

data ppnlist;
  set ppnlist;
  by ppn;
  if first.ppn;  /* Since we are sorting from high to low sampyes, if the plant is actually present in 
                   cmat.csv (in any year), we will have kept the observation for sampyes=1.  Then 
                  we will retrieve info. for these plants.  */
run;

proc sql noprint;
  create table aa as 
  select a.*, b.ind as ind63, b.firmid as firmid63, b.tvs as tvs63 ,b.cfn as cfn63, b.te as te63 , b.pw as pw63
  from ppnlist as a left join cmf.cmf1963 as b
  on a.ppn=b.ppn;
  create table ppnlist as 
  select a.*, b.ind as ind67, b.firmid as firmid67, b.tvs as tvs67 ,b.cfn as cfn67, b.te as te67, b.pw as pw67
  from aa as a left join cmf.cmf1967 as b
  on a.ppn=b.ppn;
  create table aa as 
  select a.*, b.ind as ind72, b.firmid as firmid72, b.tvs as tvs72 ,b.cfn as cfn72, b.te as te72 , b.pw as pw72
  from ppnlist as a left join cmf.cmf1972 as b
  on a.ppn=b.ppn;
  create table ppnlist as 
  select a.*, b.ind as ind77, b.firmid as firmid77, b.tvs as tvs77 ,b.cfn as cfn77, b.te as te77 , b.pw as pw77
  from aa as a left join cmf.cmf1977 as b
  on a.ppn=b.ppn;
  create table aa as 
  select a.*, b.ind as ind82, b.firmid as firmid82, b.tvs as tvs82 ,b.cfn as cfn82, b.te as te82 , b.pw as pw82
  from ppnlist as a left join cmf.cmf1982 as b
  on a.ppn=b.ppn;
  create table ppnlist as 
  select a.*, b.ind as ind87, b.firmid as firmid87, b.tvs as tvs87 ,b.cfn as cfn87, b.te as te87, b.pw as pw87
  from aa as a left join cmf.cmf1987 as b
  on a.ppn=b.ppn;
  create table aa as 
  select a.*, b.ind as ind92, b.firmid as firmid92, b.tvs as tvs92 ,b.cfn as cfn92, b.te as te92, b.pw as pw92
  from ppnlist as a left join cmf.cmf1992 as b
  on a.ppn=b.ppn;
  create table ppnlist as 
  select a.*, b.ind as ind97, b.firmid as firmid97, b.tvs as tvs97 ,b.cfn as cfn97, b.te as te97, b.lbdnum, b.pw as pw97
  from aa as a left join cmf.cmf1997 as b
  on a.ppn=b.ppn;
  create table aa as 
  select a.*, b.lastyear as lastyear97
  from ppnlist as a left join lbd.lbd1997c as b
  on a.lbdnum=b.lbdnum AND b.lbdnum~="";

proc export data=aa    outfile = "ppnlist.csv"    replace    dbms = CSV;    delimiter = ',';run;  

/* This is the main dataset that we will be working with in analysis_rev.do */
proc export data=product     outfile = "cmat.csv"    replace    dbms = CSV;    delimiter = ',';run;  

/* Get limestone employment for each county.
This dataset is not actually part of anything 
used in the paper, but was for a check to see
if we coule use limestone production as an instrument
for cement prices (in the regressions which tried to 
estimate the elasticity of substitution between cement 
and gravel/sand) 
 */

%macro oneyear3(yr);

%let c=c;
%let yrc=&yr&c;

data l1 (keep= emp county state firmid year);
  set lbd.lbd&yrc;
  if substr(bestsic,1,4)="1422" AND emp~=.;
  year=&yr;
run;

proc append base=limestone data=l1;

%mend;

%oneyear3(1977);
%oneyear3(1982);
%oneyear3(1987);

proc export data=limestone     outfile = "limestone.csv"    replace    dbms = CSV;    delimiter = ','; run;  

/* Get the establishments who are sampled, in the Commodity Flow Survey,
 from both years from either a) cement or b) paperboard.  For these plants we
will try to determine how persistent buyer-supplier relationships are.

 */

data cfsFullSamp (keep=cfn weight mileage stcc vs cfs_wgt orig_zip dest_zip year rec_num); 
   set cfs.cfs1993;
   cfn=substr(cfn,1,10); 
   if stcc=32411 OR stcc=26311;  
   if export ~= "Y" AND export ~="1";   /* drop exports */
   rename value=vs ornl_mil=mileage;
   year=1992;
run;
data cfsFullSamp2 (keep=cfn weight mileage stcc vs p_finwgt orig_zipN dest_zipN year rec_num); 
   set cfs.cfs1997;
   cfn=substr(cfn,1,10); 
   if sctg="31100" OR  sctg="27319" OR sctg="27320"; 
          /* Note that the commodity code changes across years */
   stcc=sctg/1;
   dest_zipN=dest_zip/1;
   orig_zipN=orig_zip/1;
   year=1997;
run;

data  cm3;
  set cmf.cmf1992prod;
  if substr(curpc, 1,5)="26311"  then group=1; 
  else if substr(curpc, 1,5)="26313" OR substr(curpc,1,5)="26314" then group=2;
  if  curpc="3241012" then group=3;   /* Portland cement, ASTM type 1 */
  else if curpc="3241013" OR curpc="3241014" OR curpc="3241016"  then group=4; /* Portland cement, ASTM types 2-4 */
  if group ~=.;
  if pqs>0;  /* Only keep plants that have information on quantity output */
  if pqsf ~= "I" AND pqsf ~="B";         
  price=pv/pqs;
  year=1992;
run;

data  cm3a;
  set cmf.cmf1997prod;
  if substr(curpc, 1,5)="26311"  then group=1;  /* The first four groups are the suppliers of the materials 
                                                 purchased by cardboard box makers.  (in the end, I will only use groups 1 & 3) 
                                                The last two groups are of cardboard box makers.  I broke out cardboard box makers 
                                                into these groups by the relative density of the different types of boxes.  */
  else if substr(curpc, 1,5)="26313" OR substr(curpc,1,5)="26314" then group=2;
  if  curpc="3241012" then group=3;   /* Portland cement, ASTM type 1 */
  else if curpc="3241013" OR curpc="3241014" OR curpc="3241016"  then group=4; /* Portland cement, ASTM types 2-4 */
  if group ~=.;
  if pqs>0;  /* Only keep plants that have information on quantity output */
  if pqsf ~= "I" AND pqsf ~="B";
  price=pv/pqs;
  year=1997;
run;

proc append base=cm3 data=cm3a;

proc sort data=cm3;
   by cfn group year;
run;

proc summary data=cm3;
  var pv;
  output out=sumval (drop=_type_ _freq_) sum=sumval;
  by cfn group year;
run;

proc summary data=cm3;
  var pqs;
 output out=sumquant (drop=_type_ _freq_) sum=sumquant;
  by cfn group year;
run;

proc sql noprint; 
  create table c3 as
  select a.*, b.sumval
  from cm3 as a, sumval as b
  where a.cfn=b.cfn AND a.year=b.year AND a.group=b.group;
  create table cm3 as
  select a.*, b.sumquant
  from c3 as a, sumquant as b
  where a.cfn=b.cfn AND a.year=b.year AND a.group=b.group;

proc sort data=cm3;
  by cfn year DESCENDING sumval ;
run;

data cm3a;  
  set cm3;
  by cfn year;  
  if first.year;
  fracOut=sumval/tvs;
  priceOut=sumval/sumquant;
  keep sumval sumquant fracOut priceOut group cfn year ind ppc;
  if fracOut>=.5;   /* Again, drop establishments which are not specialized in the products of interest */
run;

data cm2 (keep=ind cfn ppn ph bae mae tae ppc  pe ee cm sw ww lbdnum year div fcm2  ar reg tvs survu_id cp cr cw mib mie firmid);
  set cmf.cmf1992;
  if ar~=1;
run;
data cm2a (keep=ind cfn ppn ph bae mae tae ppc  pe ee cm sw ww lbdnum year div fcm2  ar reg tvs survu_id cp cr cw mib mie firmid);
  set cmf.cmf1997;
  if ar~=1;
run;

proc append base=cm2 data=cm2a;

proc sql noprint;
  create table cm1 as 
  select a.*, b.*
  from cm2 as a,  cm3a as b
  where a.cfn=b.cfn AND a.year=b.year;
   create table cm1a as 
   select a.*, b.iae, b.iake, b.iaks, b.ial, b.iam, b.eqrkl, b.strkl, piinve, piinvs, pimat
   from cm1 as a, outside.external as b
   where a.ind=b.myind and a.year=b.year;

data cm1a;   
   set cm1a;
   if year>=1992 then bae=tae*(1-iake/(iake+iaks));
   if year>=1992 then mae=tae*(iake/(iake+iaks));
   vm=cr+cp+cw+(mib-mie);
   lpq=log(sumquant/fracOut);
   lbae=log(bae/strkl);
   lmae=log(mae/eqrkl);
   lmatM=log((vm)/pimat);
   lmatE=log((ee)/pimat);
   lte=log(ph*sw/ww);
   ltfpq=lpq-lbae*iaks-lmae*iake-ial*lte-lmatM*iam-lmatE*iae; 
   if ltfpq=. then delete; 
run;

proc sql noprint;
   create table cfs1 as 
   select a.*, b.lbdnum, b.firmid, b.emp
   from cfsFullSamp as a, lbd.lbd1992c as b  /* Merge with the LBD.  Since the CFS samples were formed in the year 
                                               preceding the conduction of the survey, go back one year */
   where a.cfn=b.cfn;
   create table cfs2 as 
   select a.*, b.lbdnum, b.firmid, b.emp
   from cfsFullSamp2 as a, lbd.lbd1996c as b
   where a.cfn=b.cfn;

data cfs2;
   set cfs2;
   rename p_finwgt=cfs_wgt;  /* Names of some of the variables changes across years.
                              Re-name to keep everything consistent */
   rename dest_zipN=dest_zip;
   rename orig_zipN=orig_zip;
run;

proc append base=cfs1 data=cfs2 force;

proc sql noprint;
   create table persist as 
   select a.*, b.ltfpq, b.priceout, b.group as groupTFP
   from cfs1 as a, cm1a as b
   where a.cfn=b.cfn AND a.year=b.year;

proc export data=persist    outfile = "persist.csv"    replace    dbms = CSV;    delimiter = ',';run;  

/* Also for disclosure reasons, get the full sample of plants within these two industries, for 1992 
   and 1997 (just to check the implied sample.) */

data c1 (keep=emp tvs firmid lbdnum cfn ind);
   set cmf.cmf1992;
   if ind=3241 OR ind=2631;
run;
data c2 (keep=emp tvs firmid lbdnum cfn ind);
   set cmf.cmf1997;
   if ind=3241 OR ind=2631;
run;
proc append base=c1 data=c2;

proc export data=c1    outfile = "twoinds.csv"    replace    dbms = CSV;    delimiter = ','; run;

/* For these firms, also get information the zip codes in which these firms 
   have establishments.  This will be useful, since the apparent persistence of buyer-supplier
   relationships may be caused by vertical intra-firm relationships (which we want to control for) */

data firmlocs (keep=year firmid zip5);
  set lbd.lbd1997c;
  if emp~=.;
  zip5=substr(zip,1,5);
  year=1997;
run;

proc sort data=firmlocs nodupkey;
  by firmid zip5 year;
run;

proc export data=firmlocs    outfile = "firmlocs.csv"    replace    dbms = CSV;    delimiter = ',';run;  

/* Beginning here, we download the following info for cardboard box producers:
   their material inputs, their productivity, and the productivity of their suppliers 
   (the matching will occur via the CFS.  We say that a buyer-supplier relationship exists 
   if the supplier sends some shipments to the zip-code in which the buyer resides.)  */

data  cm3;
  set cmf.cmf1992prod;
  if substr(curpc, 1,5)="26311"  then group=1;  /* The first four groups are the suppliers of the materials 
                                                purchased by cardboard box makers.  (in the end, I will only use groups 1 & 3) 
                                                The last two groups are of cardboard box makers.  I broke out cardboard box makers 
                                                into these groups by the relative density of the different types of boxes.  */
  else if substr(curpc, 1,5)="26312" then group=2;
  else if substr(curpc, 1,5)="26313" OR substr(curpc,1,5)="26314" then group=3;
  else if substr(curpc, 1,5)="26217" then group=4; 
  else if curpc="2653012" OR curpc="2653013" OR curpc="2653015" OR curpc="2653014" then group=8;
  else if curpc="2653016" OR curpc="2653018" OR curpc="2653021" OR curpc="2653022" OR curpc="2653029"  OR curpc="2653030" then group=9;
  if group ~=.;
  if pqs>0;  /* Only keep plants that have information on quantity output */
  if pqsf ~= "I" AND pqsf ~="B";
  price=pv/pqs;
  year=1992;
run;

data  cm3b;
  set cmf.cmf1997prod;
  if substr(curpc, 1,5)="26311" then group=1;  
  else if substr(curpc, 1,5)="26312" then group=2;
  else if substr(curpc, 1,5)="26313" OR substr(curpc,1,5)="26314" then group=3;
  else if substr(curpc, 1,5)="26217" then group=4; 
  else if curpc="2653012" OR curpc="2653013" OR curpc="2653015" OR curpc="2653014" then group=8;
  else if curpc="2653016" OR curpc="2653018" OR curpc="2653021" OR curpc="2653022" OR curpc="2653029" OR curpc="2653030" then group=9; 
  if group ~=.;
  if pqs>0;
  if pqsf ~= "I" AND pqsf ~="B";
  price=pv/pqs;
  year=1997;
run;

proc append base=cm3 data=cm3b;

proc sort data=cm3;
   by cfn group year;
run;

proc summary data=cm3;
  var pv;
  output out=sumval (drop=_type_ _freq_) sum=sumval;
  by cfn group year;
run;

proc summary data=cm3;
  var pqs;
 output out=sumquant (drop=_type_ _freq_) sum=sumquant;
  by cfn group year;
run;

proc sql noprint; 
  create table c3 as
  select a.*, b.sumval
  from cm3 as a, sumval as b
  where a.cfn=b.cfn AND a.year=b.year AND a.group=b.group;
  create table cm3 as
  select a.*, b.sumquant
  from c3 as a, sumquant as b
  where a.cfn=b.cfn AND a.year=b.year AND a.group=b.group;

proc sort data=cm3;
  by cfn year DESCENDING sumval ;
run;

data cm3a;  
  set cm3;
  by cfn year;  
  if first.year;
  fracOut=sumval/tvs;
  priceOut=sumval/sumquant;
  keep sumval sumquant fracOut priceOut group cfn year ind ppc;
  if fracOut>=.5 AND group>=7;  /* Only keep plants that earn more than half of their output from cardboard boxes */
run;

data cm3;
  set cm3;
  by cfn year;  
  if first.year;
  fracOut=sumval/tvs;
  priceOut=sumval/sumquant;
  keep sumval sumquant fracOut priceOut group cfn year ind ppc;
  if fracOut>=.5 AND group<7; /* Only keep plants that earn more than half of their output from materials
                               purchased by makers of cardboard boxes */
run;

data cm2 (keep=ind cfn ppn ph bae mae tae ppc  pe ee cm sw ww lbdnum year div fcm2  ar reg tvs survu_id cp cr cw mib mie firmid);
  set cmf.cmf1992;
  if ar~=1;    /* Drop Administrative Record establishments */
run;
data cm2a (keep=ind cfn ppn ph bae mae tae ppc  pe ee cm sw ww lbdnum year div fcm2  ar reg tvs survu_id cp cr cw mib mie firmid);
  set cmf.cmf1997;
  if ar~=1;
run;

proc append base=cm2 data=cm2a;

proc sql noprint;
  create table cm1 as 
  select a.*, b.*
  from cm2 as a,  cm3 as b
  where a.cfn=b.cfn AND a.year=b.year;

data cfs1 (keep=rec_num origzip destzip cfn vs weight cfs_wgt stcc mileage year mode);
  set cfs.cfs1993;
  year=1992;
  cfn=substr(cfn,1,10); 
  firstdig=substr(cfn,1,1);
  if export ~= "Y" AND export ~="1";  /* Drop exports, since these (most likely) do not represent actual buyer-supplier relationships */
  rename dest_zip=destzip;
  rename orig_zip=origzip;
  rename ornl_mil=mileage value=vs orig_st=orig_fipsst dest_st=dest_fipsst ; 
  rename rmode=mode;
run;
data cfs1b (keep=rec_num origzip destzip cfn vs weight cfs_wgt stcc mileage year mode);
  set cfs.cfs1997;
  year=1997;
  cfn=substr(cfn,1,10); 
  firstdig=substr(cfn,1,1);
  if export ~= "Y" AND export ~="1";
  origzip=orig_zip/1;  /* Zip codes are coded as numbers in 1993 and as string variables in 1997 */
  destzip=dest_zip/1;
  stcc=sctg/1;  /* The commodity is codes as a number in 1993 and a string variable in 1997 */
  rename p_finwgt=cfs_wgt;
  rename orig_st=orig_fipsst dest_st=dest_fipsst ; 
run;

proc sort data=cfs1; by cfn stcc; run;
proc sort data=cfs1b; by cfn stcc; run;
proc summary data=cfs1; var vs weight; output out=ss1 (drop=_type_ _freq_) sum(vs weight)=vsS weightS; by cfn stcc; run;
proc summary data=cfs1b; var vs weight; output out=ss1b (drop=_type_ _freq_) sum(vs weight)=vsS weightS; by cfn stcc; run;
proc summary data=cfs1; var rec_num; output out=m1m2 (drop=_type_ _freq_) max=m2 min=m1; by cfn; run;
proc summary data=cfs1b; var rec_num; output out=m1m2b (drop=_type_ _freq_) max=m2 min=m1; by cfn; run;
proc sql noprint;
  create table cfs1aa as 
  select a.*, b.m1, b.m2
  from cfs1 as a, m1m2 as b
  where a.cfn=b.cfn;
  create table cfs1baa as 
  select a.*, b.m1, b.m2
  from cfs1b as a, m1m2b as b
  where a.cfn=b.cfn;
  create table cfs1aaa as 
  select a.*, b.vsS, b.weightS
  from cfs1aa as a, ss1 as b
  where a.cfn=b.cfn AND a.stcc=b.stcc;
  create table cfs1baaa as 
  select a.*, b.vsS, b.weightS
  from cfs1baa as a, ss1b as b
  where a.cfn=b.cfn AND a.stcc=b.stcc;

/* We will impute the quarter of the shipment from the record number.  Here, the presumption is that the survey respondent reports
  the same number of shipments per quarter. */

data cfs1 (drop=m1 m2);
  set cfs1aaa;
  qtr=ceil(4*(rec_num-m1+1)/(1+m2-m1));  
run;
data cfs1b (drop=m1 m2);
  set cfs1baaa;
  qtr=ceil(4*(rec_num-m1+1)/(1+m2-m1));
run;
proc append base=cfs1 data=cfs1b force;
data cfs1;
  set cfs1;
  rename destzip=dest_zip;
  rename origzip=orig_zip;
run;

proc export data=cfs1    outfile = "cfsFull.csv"    replace    dbms = CSV;    delimiter = ',';run;  

proc sql noprint;
  create table cfs as 
  select a.*, b.*
  from cfs1 as a, cm1 as b
  where a.cfn=b.cfn AND a.year=b.year;

proc sql noprint;  /* outside.external is the dataset on industry-level factor shares and price indices, from Foster & Haltiwanger */
   create table produc as 
   select a.*, b.iae, b.iake, b.iaks, b.ial, b.iam, b.eqrkl, b.strkl, piinve, piinvs, pimat
   from cfs as a, outside.external as b
   where a.ind=b.myind and a.year=b.year;

data product;    /* Compute some plant level statistics for the upstream plants
                  This data step (which is repeated several times, below) is from C. Syverson */
   set produc;
   if year=1997 then bae=tae*(1-iake/(iake+iaks));
   if year=1997 then mae=tae*(iake/(iake+iaks));
   vm=cr+cp+cw+(mib-mie);
   lpq=log(sumquant/fracOut);
   lbae=log(bae/strkl);
   lmae=log(mae/eqrkl);
   lmatM=log((vm)/pimat);
   lmatE=log((ee)/pimat);
   lte=log(ph*sw/ww);   /* Impute the total number of worker-hours from the number of hours of production workers.  Here the presumption is that 
                           the wage-rate paid to production and nonproduction workers, within each given plant, is equal.  This same 
                           assumption is made in Foster, Haltiwanger, and Syverson (2008). */
   ltfpq=lpq-lbae*iaks-lmae*iake-ial*lte-lmatM*iam-lmatE*iae; 
run;

data down (keep = lbdnum sic4D zip5 firmid empD year);                        
   set lbd.lbd1993c;  
   sic4D=substr(bestsic,1,4)/1;
   if sic4D=2657 OR sic4D=2653; /* The sample of potential receivers of paperboard are cardboard box makers (2653)  
                                 and paperboard box makers(2657) */
   zip5=substr(zip,1,5)/1;
   rename firmid=firmidD;
   rename emp=empD;
   year=1992;
run;

data downA (keep = lbdnum sic4D zip5 firmid empD year);
   set lbd.lbd1997c;
   sic4D=substr(bestsic,1,4)/1;
   if sic4D=2657 OR sic4D=2653;
   zip5=substr(zip,1,5)/1;
   rename firmid=firmidD;
   rename emp=empD;
   year=1997;
run;

proc append base=down data=downA;

data cmM (keep= year cfn ppn cp m  mc mcf mf mqdc mqdcf mqpc tvmc survu_id);
  set cmf.cmf1992mat;
  year=1992;
  if m="260003";    /* This is the materials code for paper */
run;
data cmMa (keep= year cfn ppn cp m  mc mcf mf mqdc mqdcf mqpc tvmc survu_id);
  set cmf.cmf1997mat;
  year=1997;
  if m="260003";
run;

proc append base=cmM data=cmMa;

proc sql noprint;
  create table downD as
  select a.*, b.*
  from down as a left join cm2 as b
  on a.lbdnum=b.lbdnum AND a.year=b.year;
  create table down as
  select a.*, b.*
  from downD as a left join cm3a as b
  on a.cfn=b.cfn AND a.year=b.year;
  create table downD as 
  select a.*, b.iae, b.iake, b.iaks, b.ial, b.iam, b.eqrkl, b.strkl, piinve, piinvs, pimat
  from down as a, outside.external as b
  where 2653=b.myind and (a.year=b.year);
  create table productD as 
  select a.*, b.*
  from downD as a left join cmM as b
  on a.cfn=b.cfn AND a.year=b.year;

data productD (drop=ppd ar);  /* Compute some plant level statistics for the downstream plants */
   set productD;
   if year=1997 then bae=tae*(1-iake/(iake+iaks));
   if year=1997 then mae=tae*(iake/(iake+iaks));
   vmD=cr+cp+cw+(mib-mie);
   lpqD=log(sumquant/fracOut);
   lbaeD=log(bae/strkl);
   lmaeD=log(mae/eqrkl);
   lmatMD=log((vmD)/pimat);
   lmatED=log((ee)/pimat);
   lteD=log(ph*sw/ww);
   ltfpqD=lpqD-lbaeD*iaks-lmaeD*iake-ial*lteD-lmatMD*iam-lmatED*iae;
run;

data productD;
   set productD;
   rename group=groupD;
   rename sumval=sumvalD sumquant=sumquantD fracOut=fracoutD priceOut=priceoutD cfn=cfnD ind=indD tvs=tvsD bae=baeD;
   rename cm=cmD cp=cpD cr=crD ppc=ppcD cw=cwD ee=eeD fcm2=fcm2D firmid=firmidD reg=regD div=divD mae=maeD mib=mibD;
   rename mie=mieD ph=phD tae=taeD ww=wwD iae=iaeD iake=iakeD iaks=iaksD ial=ialD iam=iamD eqrkl=eqrklD strkl=strklD;
   rename piinve=piinveD piinvs=piinvsD pimat=pimatD;
   rename lbdnum=lbdnumD;
run;

proc sql noprint;    /* Match on the zip code of the shipment to the ship code of the downstream plant */
  create table prod as 
  select a.*, b.*
  from productD as a right join product as b
  on a.zip5=b.dest_zip AND a.year=b.year;

proc export data=prod    outfile = "boxesCFS.csv"    replace    dbms = CSV;    delimiter = ',';run;  

/* Now dow the same thing, but for cement/concrete manufacturers, instead of paperboard/cardboard box manufacturers.
   Here, we will only download data from 1992-3, as production data for concrete/cement manufacturers is incomplete, for 
   1997  */

data  cm3;
  set cmf.cmf1992prod;
  if  curpc="3241012" then group=1;   /* Portland cement, ASTM type 1 */
  else if curpc="3241013" OR curpc="3241014" OR curpc="3241016"  then group=2; /* Portland cement, ASTM types 2-4 */
  else if curpc="3273000" OR curpc="3273011" then group=3;
  if group ~=.;
  if pqs>0;
  if pqsf~= "I" & pqsf~="B";
  price=pv/pqs;
  year=1992;
run;

proc sort data=cm3;
  by group curpc;
run;

proc summary data=cm3;
  var price;
  output out=prices (drop=_type_ _freq_) n=count  mean=mnprice stddev=sdprice;
  by group;
run;

proc sort data=cm3;
   by cfn;
run;

proc summary data=cm3;
  var pv;
  output out=sumval (drop=_type_ _freq_) sum=sumval;
  by cfn;
run;

proc summary data=cm3;
  var pqs;
 output out=sumquant (drop=_type_ _freq_) sum=sumquant;
  by cfn;
run;

proc sql noprint; 
  create table c3 as
  select a.*, b.sumval
  from cm3 as a, sumval as b
  where a.cfn=b.cfn;
  create table cm3 as
  select a.*, b.sumquant
  from c3 as a, sumquant as b
  where a.cfn=b.cfn;

data cm3d;  
  set cm3;
  by cfn;  
  if first.cfn;
  fracOut=sumval/tvs;
  priceOut=sumval/sumquant;
  keep sumval sumquant fracOut priceOut group cfn ppn;
  if fracOut>=.5 AND group=3;
run;

data cm3c (keep=cfn ppn cp m  mc mcf mf mqdc mqdcf mqpc tvmc survu_id);
  set cmf.cmf1987mat;
  if m="324101" AND mqdc>0;  /* This is the materials code for cement. */
run;

proc sql noprint;
  create table cm3a as 
  select a.*, b.*
  from cm3d as a left join cm3c as b
  on a.ppn=b.ppn;

data cm3;
  set cm3;
  by cfn;  
  if first.cfn;
  fracOut=sumval/tvs;
  priceOut=sumval/sumquant;
  keep sumval sumquant fracOut priceOut group cfn;
  if fracOut>=.5 AND group<3;
run;

data cm2 (keep=ind cfn ppn ph bae mae tae ppc  pe ee cm sw ww lbdnum year div fcm2  ar reg tvs survu_id cp cr cw mib mie firmid);
  set cmf.cmf1992;
  if ar~=1;
run;

proc sql noprint;
  create table cm1 as 
  select a.*, b.*
  from cm2 as a, cm3 as b
  where a.cfn=b.cfn;

data cfs1 (keep=rec_num orig_zip dest_zip cfn vs weight cfs_wgt stcc mileage year ind mode);
  set cfs.cfs1993;
  year=1992;
  ind=3241;
  cfn=substr(cfn,1,10); 
  firstdig=substr(cfn,1,1);
  if export ~= "Y";
  rename ornl_mil=mileage value=vs orig_st=orig_fipsst dest_st=dest_fipsst ; 
  rename rmode=mode;
run;

proc sort data=cfs1; by cfn stcc; run;
proc summary data=cfs1; var vs weight; output out=ss1 (drop=_type_ _freq_) sum(vs weight)=vsS weightS; by cfn stcc; run;
proc summary data=cfs1; var rec_num; output out=m1m2 (drop=_type_ _freq_) max=m2 min=m1; by cfn; run;
proc sql noprint;
  create table cfs1aa as 
  select a.*, b.m1, b.m2
  from cfs1 as a, m1m2 as b
  where a.cfn=b.cfn;
  create table cfs1aaa as 
  select a.*, b.vsS, b.weightS
  from cfs1aa as a, ss1 as b
  where a.cfn=b.cfn AND a.stcc=b.stcc;

data cfs1 (drop=m1 m2);
  set cfs1aaa;
  qtr=ceil(4*(rec_num-m1+1)/(1+m2-m1));
run;

proc sql noprint;
  create table cfs as 
  select a.*, b.*
  from cfs1 as a, cm1 as b
  where a.cfn=b.cfn;

proc sql noprint;
   create table produc as 
   select a.*, b.iae, b.iake, b.iaks, b.ial, b.iam, b.eqrkl, b.strkl, piinve, piinvs, pimat
   from cfs as a, outside.external as b
   where a.ind=b.myind and a.year=b.year;

data product;
   set produc;
   if year=1997 then bae=tae*(1-iake/(iake+iaks));
   if year=1997 then mae=tae*(iake/(iake+iaks));
   vm=cr+cp+cw+(mib-mie);
   lpq=log(sumquant/fracOut);
   lbae=log(bae/strkl);
   lmae=log(mae/eqrkl);
   lmatM=log((vm)/pimat);
   lmatE=log((ee)/pimat);
   lte=log(ph*sw/ww);
   ltfpq=lpq-lbae*iaks-lmae*iake-ial*lte-lmatM*iam-lmatE*iae;
run;

data down (keep = lbdnum sic4D zip5 firmid empD);
   set lbd.lbd1993c;
   sic4D=substr(bestsic,1,4)/1;
   if sic4D=5032 OR sic4D=3273 OR sic4D=3272 OR (sic4D>=1610 AND sic4D<1620);
   zip5=substr(zip,1,5)/1;
   rename firmid=firmidD;
   rename emp=empD;
run;

proc sql noprint;
  create table downD as
  select a.*, b.*
  from down as a left join cm2 as b
  on a.lbdnum=b.lbdnum;
  create table down as
  select a.*, b.*
  from downD as a left join cm3a as b
  on a.cfn=b.cfn;
  create table downD as 
  select a.*, b.iae, b.iake, b.iaks, b.ial, b.iam, b.eqrkl, b.strkl, piinve, piinvs, pimat
  from down as a, outside.external as b
  where 3273=b.myind and 1993=b.year;

data productD (drop=ppd ar);
   set downD;
   if year=1997 then bae=tae*(1-iake/(iake+iaks));
   if year=1997 then mae=tae*(iake/(iake+iaks));
   vmD=cr+cp+cw+(mib-mie);
   lpqD=log(sumquant/fracOut);
   lbaeD=log(bae/strkl);
   lmaeD=log(mae/eqrkl);
   lmatMD=log((vmD)/pimat);
   lmatED=log((ee)/pimat);
   lteD=log(ph*sw/ww);
   ltfpqD=lpqD-lbaeD*iaks-lmaeD*iake-ial*lteD-lmatMD*iam-lmatED*iae;
run;

data productD (drop=year);
   set productD;
   rename group=groupD sumval=sumvalD sumquant=sumquantD fracOut=fracoutD priceOut=priceoutD cfn=cfnD ind=indD;
   rename tvs=tvsD bae=baeD cm=cmD cp=cpD cr=crD cw=cwD ee=eeD fcm2=fcm2D firmid=firmidD reg=regD div=divD;
   rename mae=maeD mib=mibD mie=mieD ph=phD tae=taeD ww=wwD iae=iaeD iake=iakeD iaks=iaksD ial=ialD iam=iamD;
   rename eqrkl=eqrklD strkl=strklD piinve=piinveD piinvs=piinvsD pimat=pimatD lbdnum=lbdnumD;
run;

proc sql noprint; 
  create table prod as 
  select a.*, b.*
  from productD as a right join product as b
  on a.zip5=b.dest_zip;

proc export data=prod    outfile = "cementCFS.csv"    replace    dbms = CSV;    delimiter = ',';run;  
